searchData={"items":[{"type":"module","title":"Tucan","doc":"A high level API interface for creating plots on top of `VegaLite`.\n\nTucan is an Elixir plotting library built on top of `VegaLite`,\ndesigned to simplify the creation of interactive and visually stunning\nplots. With `Tucan`, you can effortlessly generate a wide range of plots,\nfrom simple bar charts to complex composite plots, all while enjoying the\npower and flexibility of a clean composable functional API.\n\nTucan offers a simple API for creating most common plot types similarly\nto the widely used python packages `matplotlib` and `seaborn` without\nrequiring the end user to be familiar with the Vega Lite grammar.","ref":"Tucan.html"},{"type":"module","title":"Features - Tucan","doc":"- **Versatile Plot Types** - Tucan provides an array of plot types, including\nbar charts, line plots, scatter plots, histograms, and more, allowing you to\neffectively represent diverse data sets.\n- **Clean and consistent API** - A clean and consistent plotting API similar\nto `matplotlib` or `seaborn` is provided. You should be able to create most\ncommon plots with a single function call and minimal configuration.\n- **Grouping and Faceting** - Enhance your visualizations with grouping and\nfaceting features, enabling you to examine patterns and trends within subgroups\nof your data.\n- **Customization** - Customize your plots with ease using Tucan's utilities\nfor adjusting plot dimensions, titles, and **themes**.\n- **Thin wrapper on top of VegaLite** - All `VegaLite` functions can be used\nseamlessly with `Tucan` for advanced customizations if needed.\n- **Low level API** - A low level API with helper functions allow you to modify\nany part of a `VegaLite` specification.","ref":"Tucan.html#module-features"},{"type":"module","title":"Basic usage - Tucan","doc":"All supported plots expect as first argument some data, a `VegaLite` specification\nor a binary which is considered a url to some data. Additionally you can use\none of the available `Tucan.Datasets`.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n```\n\n> #### `Nx` support {: .neutral}\n>\n> If `:nx` is installed as a dependency you can additionally pass directly the data\n> columns as tensors. For example:\n>\n> ```tucan\n> x = Nx.linspace(-20, 20, n: 200)\n> y = Nx.pow(x, 2)\n>\n> Tucan.lineplot([x: x, y: y], \"x\", \"y\", width: 400)\n> ```\n>\n> For more details check `Tucan.new/2`.\n\nYou can apply semantic grouping by a third variable by modifying the color, the\nshape or the size of the points:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\", shape_by: \"species\")\n```\n\nAlternatively you could use the helper grouping functions:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n```\n\n> ##","ref":"Tucan.html#module-basic-usage"},{"type":"module","title":"Use the functional API carefully {: .warning} - Tucan","doc":">\n> For some plot types where transformations are applied on the input data it\n> is recommended to use the options instead of the functional API, since in the\n> first case any required grouping will also be applied to the transformations.","ref":"Tucan.html#module-use-the-functional-api-carefully-warning"},{"type":"module","title":"Composite plots - Tucan","doc":"Tucan also provides some helper functions for generating composite plots.\n`pairplot/3` can be used to plot pairwise relationships across a dataset.\n\n```tucan\nfields = [\"Beak Length (mm)\", \"Beak Depth (mm)\", \"Body Mass (g)\"]\n\nTucan.pairplot(:penguins, fields, diagonal: :density)\n```","ref":"Tucan.html#module-composite-plots"},{"type":"module","title":"Customization & Themes - Tucan","doc":"Various methods and helper modules allow you to easily modify the style of\na plot.\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\",\n  color_by: \"region\",\n  width: 400,\n  tooltip: :data\n)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n|> Tucan.Grid.set_color(:x, \"red\")\n```\n\nAdditionally `set_theme/2` allows you to set one of the supported `Tucan.Themes`.\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n|> Tucan.set_theme(:latimes)\n```","ref":"Tucan.html#module-customization-themes"},{"type":"module","title":"Encoding channels options - Tucan","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Notice that only a tiny subset of vega-lite configuration\noptions are exported in Tucan's public API. This is more than enough in most\ncases. Additionally, an optional configuration option is added for every\nencoding channel that is used, that allows you to add any vega-lite option\nor change the default options set by Tucan.\n\nFor example:\n\n```tucan\nTucan.bar(:weather, \"date\", \"date\",\n  color_by: \"weather\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :month],\n  y: [aggregate: :count]\n)\n```","ref":"Tucan.html#module-encoding-channels-options"},{"type":"function","title":"Tucan.annotate/5","doc":"Adds a `text` annotation to the given `x, y` position.","ref":"Tucan.html#annotate/5"},{"type":"function","title":"Options - Tucan.annotate/5","doc":"You can pass any of the supported [vega-lite text mark properties](https://vega.github.io/vega-lite/docs/text.html#properties).","ref":"Tucan.html#annotate/5-options"},{"type":"function","title":"Examples - Tucan.annotate/5","doc":"Multiple annotations on the same plot\n\n```tucan\nTucan.new()\n|> Tucan.annotate(15, 45, \"Dennis\", size: 25, font: \"Courier New\")\n|> Tucan.annotate(40, 35, \"José\", size: 30, color: :purple, font_weight: :bold)\n|> Tucan.annotate(20, 25, \"Joe\", size: 25, color: :red)\n|> Tucan.annotate(30, 15, \"Guido\", size: 20, color: :blue)\n|> Tucan.annotate(5, 5, \"James\", size: 10, color: :orange, angle: 30)\n|> Tucan.Scale.set_x_domain(0, 50)\n|> Tucan.Scale.set_y_domain(0, 50)\n```","ref":"Tucan.html#annotate/5-examples"},{"type":"function","title":"Tucan.area/4","doc":"Returns the specification of an area plot.","ref":"Tucan.html#area/4"},{"type":"function","title":"Options - Tucan.area/4","doc":"* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:line` (`t:boolean/0`) - Whether the line will be included in the chart The default value is `false`.\n* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, areas are stacked\n    * `:normalize` - the stacked charts are normalized\n    * `:streamgraph` - the chart is displaced around a central axis\n    * `:no_stack` - no stacking is applied The default value is `:stacked`.\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:tension` (`t:number/0`) - Depending on the interpolation type, sets the tension parameter\n\n#","ref":"Tucan.html#area/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.area/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#area/4-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.area/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#area/4-data-options"},{"type":"function","title":"Styling Options - Tucan.area/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:point_color` (`t:String.t/0`) - The color of the points\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#area/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.area/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#area/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.area/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#area/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.area/4","doc":"A simple area chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou can overlay the points and/or the line, you can change the colors of the points,\nthe line and the area if needed:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\",\n  x: [type: :temporal],\n  points: true,\n  line: true,\n  fill_color: \"#fa3456\",\n  point_color: \"orange\",\n  line_color: \"green\",\n  width: 400\n)\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nIf you add the `:color_by` property then the area charts are stacked by default. Below\nyou can see how the generic encoding options can be used in order to modify any part\nof the underlying `VegaLite` specification:\n\n```tucan\nTucan.area(:unemployment, \"date\", \"count\",\n  color_by: \"series\",\n  x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n  y: [aggregate: :sum],\n  color: [scale: [scheme: \"category20b\"]],\n  width: 300,\n  height: 200\n)\n```\n\nYou could change the mode to `:normalize` or `:streamgraph`:\n\n```tucan\nleft =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :normalize,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"normalize\")\n\nright =\n  Tucan.area(:unemployment, \"date\", \"count\",\n    color_by: \"series\",\n    mode: :streamgraph,\n    x: [type: :temporal, time_unit: :yearmonth, axis: [format: \"%Y\"]],\n    y: [aggregate: :sum]\n  )\n  |> Tucan.set_title(\"streamgraph\")\n\nTucan.hconcat([left, right])\n```\n\nOr you could disable the stacking at all:\n\n```tucan\nTucan.area(:stocks, \"date\", \"price\",\n  color_by: \"symbol\",\n  mode: :no_stack,\n  x: [type: :temporal],\n  width: 400,\n  fill_opacity: 0.4\n)\n|> Tucan.Scale.set_y_scale(:log)\n```","ref":"Tucan.html#area/4-examples"},{"type":"function","title":"Tucan.background_image/2","doc":"Adds a background image to the current plot.","ref":"Tucan.html#background_image/2"},{"type":"function","title":"Examples - Tucan.background_image/2","doc":"```tucan\n# generate some random samples\nshots =\n  for _index <- 1..30 do\n    %{x: Enum.random(10..90), y: Enum.random(10..90), team: Enum.random([:home, :away])}\n  end\n\npitch_image_url = \"https://raw.githubusercontent.com/pnezis/tucan/main/assets/soccer-field.jpeg\"\n\nTucan.scatter(shots, \"x\", \"y\", color_by: \"team\", filled: true, point_size: 80, tooltip: true)\n|> Tucan.Scale.set_xy_domain(0, 100)\n|> Tucan.Scale.set_color_scheme([\"blue\", \"red\"])\n|> Tucan.background_image(pitch_image_url)\n|> Tucan.Axes.set_enabled(false)\n|> Tucan.set_size(700, 350)\n|> Tucan.set_title(\"Shots\")\n```","ref":"Tucan.html#background_image/2-examples"},{"type":"function","title":"Tucan.bar/4","doc":"Draws a bar chart.\n\nA bar chart is consisted by a categorical `field` and a numerical `value` field that\ndefines the height of the bars. You can create a grouped bar chart by setting\nthe `:color_by` option.\n\nAdditionally you should specify the aggregate for the `y` values, if your dataset contains\nmore than one values per category.\n\nSee also `lollipop/4`.","ref":"Tucan.html#bar/4"},{"type":"function","title":"Options - Tucan.bar/4","doc":"* `:mode` - The stacking mode, applied only if `:color_by` is set. Can be one of the\n  following:\n    * `:stacked` - the default one, bars are stacked\n    * `:normalize` - the bars are stacked are normalized\n    * `:grouped` - no stacking is applied, a separate bar for each category The default value is `:stacked`.\n\n#","ref":"Tucan.html#bar/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.bar/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#bar/4-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.bar/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#bar/4-data-options"},{"type":"function","title":"Styling Options - Tucan.bar/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:corner_radius` (`t:non_neg_integer/0`) - The radius in pixels of rounded rectangles. The end radius is affected:\n\n  - For vertical bars, top-left and top-right corner radius.\n  - For horizontal bars, top-right and bottom-right corner radius.\n* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:vertical`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#bar/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.bar/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:x_offset` (`t:keyword/0`) - Extra vega lite options for the `:x_offset` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#bar/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.bar/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#bar/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.bar/4","doc":"A simple bar chart:\n\n```tucan\ndata = [\n  %{\"a\" => \"A\", \"b\" => 28}, %{\"a\" => \"B\", \"b\" => 55}, %{\"a\" => \"C\", \"b\" => 43},\n  %{\"a\" => \"D\", \"b\" => 91}, %{\"a\" => \"E\", \"b\" => 81}, %{\"a\" => \"F\", \"b\" => 53},\n  %{\"a\" => \"G\", \"b\" => 19}, %{\"a\" => \"H\", \"b\" => 87}, %{\"a\" => \"I\", \"b\" => 52}\n]\n\nTucan.bar(data, \"a\", \"b\", fill_color: \"#33245A\", corner_radius: 5)\n```\n\nYou can set a `color_by` option that will create a stacked bar chart:\n\n```tucan\nTucan.bar(:weather, \"date\", \"date\",\n  color_by: \"weather\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :month],\n  y: [aggregate: :count]\n)\n```\n\nIf you set the mode option to `:grouped` you will instead have a different bar\nper group, you can also change the orientation by setting the `:orient` flag.\nSimilarly you can set the mode to `:normalize` in order to have normalized\nstacked bars.\n\n```tucan\ndata = [\n    %{\"category\" => \"A\", \"group\" => \"x\", \"value\" => 0.1},\n    %{\"category\" => \"A\", \"group\" => \"y\", \"value\" => 0.6},\n    %{\"category\" => \"A\", \"group\" => \"z\", \"value\" => 0.9},\n    %{\"category\" => \"B\", \"group\" => \"x\", \"value\" => 0.7},\n    %{\"category\" => \"B\", \"group\" => \"y\", \"value\" => 0.2},\n    %{\"category\" => \"B\", \"group\" => \"z\", \"value\" => 1.1},\n    %{\"category\" => \"C\", \"group\" => \"x\", \"value\" => 0.6},\n    %{\"category\" => \"C\", \"group\" => \"y\", \"value\" => 0.1},\n    %{\"category\" => \"C\", \"group\" => \"z\", \"value\" => 0.2}\n]\n\ngrouped =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :grouped,\n    orient: :horizontal\n  )\n\nnormalized =\n  Tucan.bar(\n    data, \"category\", \"value\",\n    color_by: \"group\",\n    mode: :normalize\n  )\n\nTucan.hconcat([grouped, normalized])\n```","ref":"Tucan.html#bar/4-examples"},{"type":"function","title":"Tucan.boxplot/3","doc":"Returns the specification of a box plot.\n\nBy default a one dimensional box plot of the `:field` - which must be a numerical variable - is\ngenerated. You can add a second dimension across a categorical variable by either setting the\n`:group_by` or `:color_by` options.\n\nBy default a Tukey box plot will be generated. In the Tukey box plot the whisker spans from\nthe smallest data to the largest data within the range `[Q1 - k * IQR, Q3 + k * IQR]` where\n`Q1`and `Q3` are the first and third quartiles while `IQR` is the interquartile range\n`(Q3-Q1)`. You can specify if needed the constant `k` which defaults to 1.5.\n\nAdditionally you can set the `mode` to `:min_max`  where the lower and upper whiskers are\ndefined as the min and max respectively. No points will be considered as outliers for this\ntype of box plots. In this case the `k` value is ignored.\n\n> ##","ref":"Tucan.html#boxplot/3"},{"type":"function","title":"What is a box plot {: .info} - Tucan.boxplot/3","doc":">\n> A box plot (box and whisker plot) displays the five-number summary of a set of data. The\n> five-number summary is the minimum, first quartile, median, third quartile, and maximum.\n> In a box plot, we draw a box from the first quartile to the third quartile. A vertical\n> line goes through the box at the median.","ref":"Tucan.html#boxplot/3-what-is-a-box-plot-info"},{"type":"function","title":"Options - Tucan.boxplot/3","doc":"* `:k` (`t:float/0`) - The constant used for calculating the extent of the whiskers in a Tukey boxplot. Applicable\n  only if `:mode` is set to `:tukey`. The default value is `1.5`.\n* `:mode` - The type of the box plot. Either a Tukey box plot (`:tukey`) or a min-max plot (`:min_max`)\n  will be created. The default value is `:tukey`.\n\n#","ref":"Tucan.html#boxplot/3-options"},{"type":"function","title":"Data Grouping Options - Tucan.boxplot/3","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A field to be used for grouping the boxplot. It is used for adding a second dimension to\n  the plot. If not set the plot will be one dimensional. Notice that a grouping is automatically\n  applied if the `:color_by` option is set.\n\n#","ref":"Tucan.html#boxplot/3-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.boxplot/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#boxplot/3-data-options"},{"type":"function","title":"Styling Options - Tucan.boxplot/3","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#boxplot/3-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.boxplot/3","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#boxplot/3-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.boxplot/3","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#boxplot/3-interactivity-options"},{"type":"function","title":"Examples - Tucan.boxplot/3","doc":"A one dimensional Tukey boxplot:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\")\n```\n\nYou can set `:group_by` or `:color_by` in order to set a second dimension:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\n```\n\nYou can set the mode to `:min_max` in order to extend the whiskers to the min and max values:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", mode: :min_max)\n```\n\nBy setting the `:orient` to `:vertical` you can change the default horizontal orientation:\n\n```tucan\nTucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\", orient: :vertical)\n```","ref":"Tucan.html#boxplot/3-examples"},{"type":"function","title":"Tucan.bubble/5","doc":"Returns the specification of a bubble plot.\n\nA bubble plot is a scatter plot with a third parameter defining the size of the dots.\n\nAll `x`, `y` and `size` must be numerical data fields.\n\nSee also `scatter/4`.","ref":"Tucan.html#bubble/5"},{"type":"function","title":"Options - Tucan.bubble/5","doc":"#","ref":"Tucan.html#bubble/5-options"},{"type":"function","title":"Data Grouping Options - Tucan.bubble/5","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#bubble/5-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.bubble/5","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#bubble/5-data-options"},{"type":"function","title":"Styling Options - Tucan.bubble/5","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#bubble/5-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.bubble/5","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#bubble/5-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.bubble/5","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#bubble/5-interactivity-options"},{"type":"function","title":"Examples - Tucan.bubble/5","doc":"```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", width: 400)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nYou could use a fourth variable to color the graph. As always you can set the `tooltip` in\norder to make the plot interactive:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n```\n\nIt makes more sense to use a log scale for the _x axis_:\n\n```tucan\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\", color_by: \"region\", width: 400, tooltip: :data)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n```","ref":"Tucan.html#bubble/5-examples"},{"type":"function","title":"Tucan.color_by/3","doc":"Adds a `color` encoding for the given field.","ref":"Tucan.html#color_by/3"},{"type":"function","title":"Options - Tucan.color_by/3","doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#color_by/3-options"},{"type":"function","title":"Tucan.concat/2","doc":"Concatenates the given plots.\n\nThis corresponds to the general concatenation of vega-lite (wrappable).","ref":"Tucan.html#concat/2"},{"type":"function","title":"Options - Tucan.concat/2","doc":"* `:align` - The alignment to apply to grid rows and columns. The supported values are `:all`,\n  `:each`, and `:none`.\n\n  * For `:none`, a flow layout will be used, in which adjacent subviews are simply\n  placed one after the other.\n  * For `:each`, subviews will be aligned into a clean grid structure, but each row or\n  column may be of variable size.\n  * For `:all`, subviews will be aligned and each row or column will be sized identically\n  based on the maximum observed size. String values for this property will be applied to\n  both grid rows and columns.\n\n  Defaults to `:all` if not set.\n* `:bounds` - The bounds calculation method to use for determining the extent of a sub-plot. One\n  of `:full` (the default) or `:flush`.\n\n  * If set to `:full`, the entire calculated bounds (including axes, title, and legend)\n  will be used.\n  * If set to `:flush`, only the specified width and height values for the sub-view\n  will be used. The `:flush` setting can be useful when attempting to place sub-plots\n  without axes or legends into a uniform grid structure.\n* `:columns` (`t:pos_integer/0`) - The number of columns to include in the view composition layout.\n* `:spacing` (`t:pos_integer/0`) - The spacing in pixels between sub-views of the composition operator. If not set defaults\n  to 20.\n\n#","ref":"Tucan.html#concat/2-options"},{"type":"function","title":"Styling Options - Tucan.concat/2","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image","ref":"Tucan.html#concat/2-styling-options"},{"type":"function","title":"Tucan.countplot/3","doc":"Plot the counts of observations for a categorical variable.\n\nTakes a categorical `field` as input and generates a count plot\nvisualization. By default the counts are plotted on the *y-axis*\nand the categorical `field` across the *x-axis*.\n\nThis is similar to `histogram/3` but specifically for a categorical\nvariable.\n\nThis is a simple wrapper around `bar/4` where by default the count of\nobservations is mapped to the `y` variable.\n\n> ##","ref":"Tucan.html#countplot/3"},{"type":"function","title":"What is a countplot? {: .tip} - Tucan.countplot/3","doc":">\n> A countplot is a type of bar chart used in data visualization to\n> display the **frequency of occurrences of categorical data**. It is\n> particularly useful for visualizing the *distribution* and *frequency*\n> of different categories within a dataset.\n>\n> In a countplot, each unique category is represented by a bar, and the\n> height of the bar corresponds to the number of occurrences of that\n> category in the data.","ref":"Tucan.html#countplot/3-what-is-a-countplot-tip"},{"type":"function","title":"Options - Tucan.countplot/3","doc":"See `bar/4`","ref":"Tucan.html#countplot/3-options"},{"type":"function","title":"Examples - Tucan.countplot/3","doc":"We will use the `:titanic` dataset on the following examples. We can\nplot the number of passengers by ticket class:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\")\n```\n\nYou can make the bars horizontal by setting the `:orient` option:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", orient: :horizontal)\n```\n\nYou can set `:color_by` to group it by a second variable:\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\")\n```\n\nBy default the bars are stacked. You can unstack them by setting the\n`:mode` to `:grouped`\n\n```tucan\nTucan.countplot(:titanic, \"Pclass\", color_by: \"Survived\", mode: :grouped)\n```","ref":"Tucan.html#countplot/3-examples"},{"type":"function","title":"Tucan.density/3","doc":"Plot the distribution of a numeric variable.\n\nDensity plots allow you to visualize the distribution of a numeric variable for one\nor several groups. If you want to draw the density for several groups you need to\nspecify the `:color_by` option which is assumed to be a categorical variable.\n\n> #","ref":"Tucan.html#density/3"},{"type":"function","title":"Avoid calling `color_by/3` with a density plot {: .warning} - Tucan.density/3","doc":">\n> Since the grouping variable must also be used for properly calculating the density\n> transformation you **should avoid calling the `color_by/3` grouping function** after\n> a `density/3` call. Instead use the `:color_by` option, which will ensure that the\n> proper settings are applied to the underlying transformation.\n>\n> Calling `color_by/3` would produce this graph:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\")\n> |> Tucan.color_by(\"Species\")\n> ```\n>\n> In the above case the density function has been calculated on the complete dataset\n> and you cannot color by the `Species`. Instead you should use the `:color_by`\n> option which would calculate the density function per group:\n>\n> ```tucan\n> Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n> ```\n>\n> Alternatively you should use the `:group_by` option in order to group the density\n> transform by the `Species` field and then apply the `color_by/3` function:\n>\n> ```elixir\n> Tucan.density(:penguins, \"Body Mass (g)\", group_by: [\"Species\"], fill_opacity: 0.2)\n> |> Tucan.color_by(\"Species\")\n> ```\n\nSee also `histogram/3`.","ref":"Tucan.html#density/3-avoid-calling-color_by-3-with-a-density-plot-warning"},{"type":"function","title":"Options - Tucan.density/3","doc":"* `:bandwidth` (`t:float/0`) - The bandwidth (standard deviation) of the Gaussian kernel. If unspecified or set to\n  zero, the bandwidth value is automatically estimated from the input data using\n  Scott’s rule.\n* `:counts` (`t:boolean/0`) - A boolean flag indicating if the output values should be probability estimates\n  (false) or smoothed counts (true). The default value is `false`.\n* `:cumulative` (`t:boolean/0`) - A boolean flag indicating whether to produce density estimates (false) or cumulative\n  density estimates (true). The default value is `false`.\n* `:extent` - A `[min, max]` domain from which to sample the distribution. If unspecified, the extent\n  will be determined by the observed minimum and maximum values of the density value field.\n* `:group_by` (list of `t:String.t/0`) - The data fields to group by. If not specified, a single group containing all data\n  objects will be used. This is applied only on the density transform.\n\n  In most cases you only need to set `:color_by` which will automatically handle the\n  density transform grouping. Use `:group_by` only if you want to manually post-process\n  the generated specification, or if you want to apply grouping by more than one\n  variable.\n\n  If both `:group_by` and `:color_by` are set then only `:group_by` is used for grouping\n  the density transform and `color_by` is used for encoding the color.\n* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:maxsteps` (`t:integer/0`) - The maximum number of samples to take along the extent domain for plotting the density. The default value is `200`.\n* `:minsteps` (`t:integer/0`) - The minimum number of samples to take along the extent domain for plotting the density. The default value is `25`.\n* `:stacked` (`t:boolean/0`) - Whether the density plots will be stacked or not. The default value is `false`.\n* `:steps` (`t:integer/0`) - The exact number of samples to take along the extent domain for plotting the density. If\n  specified, overrides both minsteps and maxsteps to set an exact number of uniform samples.\n  Potentially useful in conjunction with a fixed extent to ensure consistent sample points\n  for stacked densities.\n\n#","ref":"Tucan.html#density/3-options"},{"type":"function","title":"Data Grouping Options - Tucan.density/3","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#density/3-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.density/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#density/3-data-options"},{"type":"function","title":"Styling Options - Tucan.density/3","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:filled` (`t:boolean/0`) - Whether the density plot will be filled or not, default to `true` if not set\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#density/3-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.density/3","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#density/3-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.density/3","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#density/3-interactivity-options"},{"type":"function","title":"Examples - Tucan.density/3","doc":"```tucan\nTucan.density(:penguins, \"Body Mass (g)\")\n```\n\nIt is a common use case to compare the density of several groups in a dataset. Several\noptions exist to do so. You can plot all items on the same chart, using transparency and\nannotation to make the comparison possible. You can stack overlapping densities by\nsetting the `:stacked` property.\n\n```tucan\nunstacked =\n  Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n  |> Tucan.set_title(\"Unstacked\")\n\nstacked =\n  Tucan.density(:penguins, \"Body Mass (g)\",\n    color_by: \"Species\",\n    fill_opacity: 0.8,\n    stacked: true\n  )\n  |> Tucan.set_title(\"Stacked\")\n\nTucan.hconcat([unstacked, stacked])\n```\n\nYou can also combine it with `facet_by/4` in order to draw a different plot for each value\nof the grouping variable. Notice that we need to set the `:group_by` variable in order\nto correctly calculate the density plot per field's value.\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", group_by: [\"Species\"])\n|> Tucan.color_by(\"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```\n\nYou can control the smoothing by setting a specific `bandwidth` value (if not set it is\nautomatically calculated by vega lite):\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\",\n  color_by: \"Species\",\n  bandwidth: 50.0,\n  fill_opacity: 0.5\n)\n```\n\nYou can plot a cumulative density distribution by setting the `:cumulative` option to `true`:\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true)\n```\n\nor calculate a separate cumulative distribution for each group:\n\n```tucan\nTucan.density(:penguins, \"Body Mass (g)\", cumulative: true, color_by: \"Species\")\n|> Tucan.facet_by(:column, \"Species\")\n```\n\nYou can change the color of the plot by setting the `:fill_color` option and/or specify if it\nwill be filled or not:\n\n```tucan\nTucan.hconcat([\n  Tucan.density(:penguins, \"Body Mass (g)\", fill_color: \"red\"),\n  Tucan.density(:penguins, \"Body Mass (g)\", filled: false)\n])\n|> Tucan.set_theme(:ggplot2)\n```","ref":"Tucan.html#density/3-examples"},{"type":"function","title":"Tucan.density_heatmap/4","doc":"Draws a density heatmap.\n\nA density heatmap is a bivariate histogram, e.g. the `x`, `y` data are binned\nwithin rectangles that tile the plot and then the count of observations within\neach rectangle is shown with the fill color.\n\nBy default the `count` of observations within each rectangle is encoded, but you\ncan calculate the statistic of any field and use it instead.\n\nDensity heatmaps are a powerful visualization tool that find their best use cases\nin situations where you need to explore and understand the distribution and\nconcentration of data points in a two-dimensional space. They are particularly\neffective when dealing with large datasets, allowing you to uncover patterns,\nclusters, and trends that might be difficult to discern in raw data.","ref":"Tucan.html#density_heatmap/4"},{"type":"function","title":"Options - Tucan.density_heatmap/4","doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a bin. The\n  `z` field must be set if `aggregate` is set.\n* `:z` (`t:String.t/0`) - If set corresponds to the field that will be used for calculating the color fo the\n  bin using the provided aggregate. If not set (the default behaviour) the count of\n  observations are used for coloring the bin.\n\n#","ref":"Tucan.html#density_heatmap/4-options"},{"type":"function","title":"Data Options - Tucan.density_heatmap/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#density_heatmap/4-data-options"},{"type":"function","title":"Styling Options - Tucan.density_heatmap/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#density_heatmap/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.density_heatmap/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#density_heatmap/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.density_heatmap/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#density_heatmap/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.density_heatmap/4","doc":"Let's start with a default density heatmap on the penguins dataset:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n```\n\nYou can summarize over another field:\n\n```tucan\nTucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\", z: \"Body Mass (g)\", aggregate: :mean)\n```","ref":"Tucan.html#density_heatmap/4-examples"},{"type":"function","title":"Tucan.donut/4","doc":"Draw a donut chart.\n\nA donut chart is a circular visualization that resembles a pie chart but\nfeatures a hole at its center. This central hole creates a _donut_ shape,\ndistinguishing it from traditional pie charts.\n\nThis is a wrapper around `pie/4` that sets by default the `:inner_radius`.","ref":"Tucan.html#donut/4"},{"type":"function","title":"Options - Tucan.donut/4","doc":"See `pie/4`","ref":"Tucan.html#donut/4-options"},{"type":"function","title":"Examples - Tucan.donut/4","doc":"```tucan\nTucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#donut/4-examples"},{"type":"function","title":"Tucan.errorband/4","doc":"Draws an error band (confidence interval).\n\nAn error band summarizes an error range of quantitative values using a set of summary statistics,\nrepresented by area. Both `x` and `y` should be quantitative variables.","ref":"Tucan.html#errorband/4"},{"type":"function","title":"Options - Tucan.errorband/4","doc":"* `:borders` (`t:boolean/0`) - If set to `true` the error band's border will be added. The default value is `false`.\n* `:extent` - The extent of the rule. Can be one of the following:\n\n  * `:ci` - Extend the rule to the confidence interval of the mean.\n  * `:stderr` - The size of rule are set to the value of standard error, extending from the mean.\n  * `:stdev` - The size of rule are set to the value of standard deviation, extending from the\n  mean.\n  * `:iqr` - Extend the rule to the q1 and q3.\n\n  The default value is `:stderr`.\n* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n\n#","ref":"Tucan.html#errorband/4-options"},{"type":"function","title":"Data Options - Tucan.errorband/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#errorband/4-data-options"},{"type":"function","title":"Styling Options - Tucan.errorband/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:stroke_dash` (list of `t:pos_integer/0`) - An array of alternating stroke, space lengths in pixels for creating dashed\n  or dotted lines.\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#errorband/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.errorband/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#errorband/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.errorband/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#errorband/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.errorband/4","doc":"```tucan\nTucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\", x: [time_unit: \"year\", type: :temporal])\n```\n\nYou can modify the look of the error band, change the `:extent` and include the borders if needed.\n\n```tucan\nTucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\",\n  extent: :ci,\n  fill_color: \"red\",\n  borders: true,\n  x: [time_unit: \"year\", type: :temporal]\n)\n```\n\nYou can also change the look of the borders:\n\n```tucan\nTucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\",\n  extent: :ci,\n  fill_color: \"black\",\n  borders: true,\n  line_color: \"red\",\n  stroke_width: 3,\n  stroke_dash: [7, 5],\n  x: [time_unit: \"year\", type: :temporal]\n)\n```\n\nUsually you want to combine the errorband with the mean trend line. You can use\n`Tucan.layers/2` to combine it with a lineplot.\n\n```tucan\nerrorband = Tucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\",\n  extent: :ci,\n  fill_color: \"green\",\n  x: [time_unit: \"year\", type: :temporal]\n)\n\ntrendline = Tucan.lineplot(:cars, \"Year\", \"Miles_per_Gallon\",\n  x: [time_unit: \"year\", type: :temporal],\n  y: [aggregate: :mean]\n)\n\nTucan.layers([errorband, trendline])\n```\n\nSimilar to other Tucan plots you can apply semantic grouping:\n\n```tucan\nerrorband = Tucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\",\n  extent: :ci,\n  x: [time_unit: \"year\", type: :temporal]\n)\n\ntrendline = Tucan.lineplot(:cars, \"Year\", \"Miles_per_Gallon\",\n  x: [time_unit: \"year\", type: :temporal],\n  y: [aggregate: :mean]\n)\n\nTucan.layers([errorband, trendline])\n|> Tucan.color_by(\"Origin\")\n|> Tucan.set_width(400)\n```","ref":"Tucan.html#errorband/4-examples"},{"type":"function","title":"Tucan.errorbar/3","doc":"Plots the errorbar for the given numerical variable `field`.\n\nError bars sho by default the standard error. It can also be explicitly specified by setting\n`:extent` to `:stderr`. The length of lower and upper rules represent standard error. By\ndefault, the rule marks expand from the mean.","ref":"Tucan.html#errorbar/3"},{"type":"function","title":"Options - Tucan.errorbar/3","doc":"* `:extent` - The extent of the rule. Can be one of the following:\n\n  * `:ci` - Extend the rule to the confidence interval of the mean.\n  * `:stderr` - The size of rule are set to the value of standard error, extending from the mean.\n  * `:stdev` - The size of rule are set to the value of standard deviation, extending from the\n  mean.\n  * `:iqr` - Extend the rule to the q1 and q3.\n\n  The default value is `:stderr`.\n* `:group_by` (`t:String.t/0`) - A field to be used for grouping the error bars by a category. If not set the plot will\n  be one dimensional.\n* `:points` (`t:boolean/0`) - If set the means of the error bar are also included.\n* `:ticks` (`t:boolean/0`) - If set ticks will be included to the error bars ends\n\n#","ref":"Tucan.html#errorbar/3-options"},{"type":"function","title":"Data Options - Tucan.errorbar/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#errorbar/3-data-options"},{"type":"function","title":"Styling Options - Tucan.errorbar/3","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:point_color` (`t:String.t/0`) - The color of the points if enabled. If not set defaults to the error bars color\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#errorbar/3-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.errorbar/3","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#errorbar/3-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.errorbar/3","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#errorbar/3-interactivity-options"},{"type":"function","title":"Examples - Tucan.errorbar/3","doc":"A 1-d error bar:\n\n```tucan\nTucan.errorbar(:barley, \"yield\")\n```\n\nBy setting the `:group_by` option you can show the error range of a continuous field\nbroken down by categories.\n\n```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\")\n```\n\nYou can change the orientation by setting the `:orient` option:\n\n```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\", orient: :vertical)\n```\n\nBy setting `:ticks` to `true` you can enable errorbar end ticks. Also you can overlay the\nmeans by setting `:points` to `true`.\n\n ```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\", ticks: true, points: true)\n```\n\nYou can change the `:extent` value in order to configure how the error bars are extended. Below\nyou can see all supported options:\n\n```tucan\nvalid_extent_values = [:ci, :stderr, :stdev, :iqr]\n\nplots =\n  for extent <- valid_extent_values do\n    Tucan.errorbar(:barley, \"yield\", group_by: \"variety\", extent: extent)\n    |> Tucan.set_title(inspect(extent) <> \" extent\")\n    |> Tucan.Axes.set_enabled(:y, extent == :ci)\n    |> Tucan.set_size(160, 160)\n  end\n\nTucan.hconcat(plots)\n```\n\nYou can use `:line_color` and `:stroke_width` to modify the look of the error bars:\n\n```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\", line_color: \"red\", stroke_width: 3, ticks: true, points: true)\n```\n\nYou can color categories by combining it with `Tucan.color_by/3`.\n\n```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\", points: true)\n|> Tucan.color_by(\"variety\")\n```","ref":"Tucan.html#errorbar/3-examples"},{"type":"function","title":"Tucan.facet_by/4","doc":"Apply facetting on the input plot `vl` by the given `field`.\n\nThis will create multiple plots either horizontally (`:column` faceting mode),\nvertically (`:row` faceting mode) or arbitrarily (`:wrapped` mode). One plot will\nbe created for each distinct value of the given `field`, which must be a\ncategorical variable.\n\nIn the case of `:wrapped` a `:columns` option should also be provided which\nwill determine the number of columns of the composite plot.\n\n`opts` is an arbitrary keyword list that will be passed to the `:row` or `:column`\nencoding.\n\n> ##","ref":"Tucan.html#facet_by/4"},{"type":"function","title":"Facet plots {: .info} - Tucan.facet_by/4","doc":">\n> Facet plots, also known as trellis plots or small multiples, are figures made up\n> of multiple subplots which have the same set of axes, where each subplot shows\n> a subset of the data.","ref":"Tucan.html#facet_by/4-facet-plots-info"},{"type":"function","title":"Examples - Tucan.facet_by/4","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.facet_by(:column, \"species\")\n|> Tucan.color_by(\"species\")\n```\n\nWith `:wrapped` mode and custom sorting:\n\n```tucan\nTucan.density(:movies, \"IMDB Rating\", color_by: \"Major Genre\")\n|> Tucan.facet_by(:wrapped, \"Major Genre\", columns: 4, sort: [op: :mean, field: \"IMDB Rating\"])\n|> Tucan.Legend.set_enabled(:color, false)\n|> Tucan.set_title(\"Density of IMDB rating by Genre\", offset: 20)\n```","ref":"Tucan.html#facet_by/4-examples"},{"type":"function","title":"Tucan.fill_by/3","doc":"Adds a `fill` encoding for the given field.","ref":"Tucan.html#fill_by/3"},{"type":"function","title":"Options - Tucan.fill_by/3","doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#fill_by/3-options"},{"type":"function","title":"Tucan.flip_axes/1","doc":"Flips the axes of the provided chart.\n\nThis works for both one dimensional and two dimensional charts. All positional channels\nthat are defined will be flipped.\n\nThis is used internally by plots that support setting orientation.","ref":"Tucan.html#flip_axes/1"},{"type":"function","title":"Tucan.hconcat/2","doc":"Concatenates horizontally the given plots.","ref":"Tucan.html#hconcat/2"},{"type":"function","title":"Options - Tucan.hconcat/2","doc":"* `:align` - The alignment to apply to grid rows and columns. The supported values are `:all`,\n  `:each`, and `:none`.\n\n  * For `:none`, a flow layout will be used, in which adjacent subviews are simply\n  placed one after the other.\n  * For `:each`, subviews will be aligned into a clean grid structure, but each row or\n  column may be of variable size.\n  * For `:all`, subviews will be aligned and each row or column will be sized identically\n  based on the maximum observed size. String values for this property will be applied to\n  both grid rows and columns.\n\n  Defaults to `:all` if not set.\n* `:bounds` - The bounds calculation method to use for determining the extent of a sub-plot. One\n  of `:full` (the default) or `:flush`.\n\n  * If set to `:full`, the entire calculated bounds (including axes, title, and legend)\n  will be used.\n  * If set to `:flush`, only the specified width and height values for the sub-view\n  will be used. The `:flush` setting can be useful when attempting to place sub-plots\n  without axes or legends into a uniform grid structure.\n* `:spacing` (`t:pos_integer/0`) - The spacing in pixels between sub-views of the composition operator. If not set defaults\n  to 20.\n\n#","ref":"Tucan.html#hconcat/2-options"},{"type":"function","title":"Styling Options - Tucan.hconcat/2","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image","ref":"Tucan.html#hconcat/2-styling-options"},{"type":"function","title":"Tucan.heatmap/5","doc":"Returns the specification of a heatmap.\n\nA heatmap is a graphical representation of data where the individual values\ncontained in a matrix are represented as colors.\n\nIt expects two categorical fields `x`, `y` which will be used for the axes\nand a numerical field `color`. If `color` is `nil` then the color represents\nthe count of the observations for each `x, y`.\n\nIf an `:aggregate` is set this statistic will be used for encoding the color.\nIf no `:aggregate` is set the color encodes by default the `:mean` of the\ndata.","ref":"Tucan.html#heatmap/5"},{"type":"function","title":"Options - Tucan.heatmap/5","doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a heatmap\n  tile. Defaults to `:mean` which in case of single data will encode the value of\n  the `color` data field.\n\n  Ignored if `:color` is set to `nil`.\n* `:annotate` (`t:boolean/0`) - If set to `true` then the values of each cell will be included in the plot. The default value is `false`.\n\n#","ref":"Tucan.html#heatmap/5-options"},{"type":"function","title":"Data Options - Tucan.heatmap/5","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#heatmap/5-data-options"},{"type":"function","title":"Styling Options - Tucan.heatmap/5","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:color_scheme` (`t:atom/0`) - The color scheme to use, for supported color schemes check `Tucan.Scale`. Notice that\n  this is just a helper option for easily setting color schemes. If you need to set\n  specific colors or customize the scheme, use `Tucan.Scale.set_color_scheme/3`.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:text_color` - The color to be used for the textual annotations. Valid only if `:annotate` is set\n  to `true`. Can be one of the following:\n  * a `string` with the color to be used, e.g. `\"white\"`\n  * a list of tuples of the form `{low_threshold, upper_threshold, color}` for\n  conditionally setting the color based on the value of the annotated variable.\n  `low_threshold` and `upper_threshold` can either be a number or `nil`. For example\n  `[{nil, 0, \"green\"}, {0, 5, \"red\"}, {5, nil, \"white\"}]` will apply the following\n  colors:\n    * `green` for all items with `value < 0`\n    * `red` for all items with `value >= 0 && value < 5`\n    * `white` for all items with `value >= 5`\n  Notice that the `low_threshold`, `upper_threshold` correspond to the\n  `[low_threshold, upper_threshold)` range.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#heatmap/5-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.heatmap/5","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:text` (`t:keyword/0`) - Extra vega lite options for the `:text` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#heatmap/5-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.heatmap/5","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#heatmap/5-interactivity-options"},{"type":"function","title":"Examples - Tucan.heatmap/5","doc":"A simple heatmap of two categorical variables, using a third one for the\ncolor values.\n\n```tucan\ndata = [\n  %{\"x\" => \"A\", \"y\" => \"K\", \"value\" => 0.5},\n  %{\"x\" => \"A\", \"y\" => \"L\", \"value\" => 1.5},\n  %{\"x\" => \"A\", \"y\" => \"M\", \"value\" => 4.5},\n  %{\"x\" => \"B\", \"y\" => \"K\", \"value\" => 1.5},\n  %{\"x\" => \"B\", \"y\" => \"L\", \"value\" => 2.5},\n  %{\"x\" => \"B\", \"y\" => \"M\", \"value\" => 0.5},\n  %{\"x\" => \"C\", \"y\" => \"K\", \"value\" => -1.5},\n  %{\"x\" => \"C\", \"y\" => \"L\", \"value\" => 5.5},\n  %{\"x\" => \"C\", \"y\" => \"M\", \"value\" => 1.5},\n]\n\nTucan.heatmap(data, \"x\", \"y\", \"value\", width: 200, height: 200)\n```\n\nYou can change the color scheme:\n\n```tucan\nTucan.heatmap(:glue, \"Task\", \"Model\", \"Score\", color_scheme: :redyellowgreen, tooltip: true)\n```\n\nHeatmaps are also useful for visualizing temporal data. Let's use a heatmap to examine\nhow Seattle's max temperature changes over the year. On the _x-axis_ we will encode the\ndays of the month along the x-axis, and the months on the _y-axis_. We will aggregate\nover the max temperature for the color field. (example borrowed from\n[here](https://observablehq.com/@jonfroehlich/basic-time-series-plots-in-vega-lite?collection=@jonfroehlich/intro-to-vega-lite))\n\n```tucan\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month],\n  tooltip: true\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n```\n\nYou can enable annotations by setting the `:annotate` flag. Notice that you can conditionally\ncolor the annotation text by setting the `:text_color` option. It expects a list of tuples\ncorresponding to `{lower_threshold, upper_threshold, color}`. Below we color white everything\nbelow 0 and black everything with a value `>=0`.\n\n```tucan\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  annotate: true,\n  text_color: [{nil, 5, \"white\"}, {5, 25, \"black\"}, {25, nil, \"white\"}],\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month],\n  text: [format: \".1f\"],\n  tooltip: true,\n  width: 800\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n```","ref":"Tucan.html#heatmap/5-examples"},{"type":"function","title":"Tucan.histogram/3","doc":"Plots a histogram.\n\nSee also `density/3`","ref":"Tucan.html#histogram/3"},{"type":"function","title":"Options - Tucan.histogram/3","doc":"* `:extent` - A two-element (`[min, max]`) array indicating the range of desired bin values.\n* `:maxbins` (`t:integer/0`) - Maximum number of bins.\n* `:orient` - Histogram's orientation. It specifies the axis along which the field values\n  are plotted. The default value is `:horizontal`.\n* `:relative` (`t:boolean/0`) - If set a relative frequency histogram is generated. The default value is `false`.\n* `:stacked` (`t:boolean/0`) - If set it will stack the group histograms instead of layering one over another. Valid\n  only if a semantic grouping has been applied.\n* `:step` - An exact step size to use between bins. If provided, options such as `maxbins`\n  will be ignored.\n\n#","ref":"Tucan.html#histogram/3-options"},{"type":"function","title":"Data Grouping Options - Tucan.histogram/3","doc":"* `:color_by` (`t:String.t/0`) - The field to group observations by. This will used for coloring the histogram\n  if set.\n\n#","ref":"Tucan.html#histogram/3-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.histogram/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#histogram/3-data-options"},{"type":"function","title":"Styling Options - Tucan.histogram/3","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:corner_radius` (`t:non_neg_integer/0`) - The radius in pixels of rounded rectangles. The end radius is affected:\n\n  - For vertical bars, top-left and top-right corner radius.\n  - For horizontal bars, top-right and bottom-right corner radius.\n* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#histogram/3-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.histogram/3","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:x2` (`t:keyword/0`) - Extra vega lite options for the `:x2` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#histogram/3-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.histogram/3","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#histogram/3-interactivity-options"},{"type":"function","title":"Examples - Tucan.histogram/3","doc":"Histogram of `Horsepower`\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\")\n```\n\nYou can flip the plot by setting the `:orient` option to `:vertical`:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", orient: :vertical)\n```\n\nYou can also modify the default color and add a radius to the histogram bars:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", orient: :vertical, fill_color: \"red\", corner_radius: 5)\n```\n\nBy setting the `:relative` flag you can get a relative frequency histogram:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", relative: true)\n```\n\nYou can increase the number of bins by settings the `maxbins` or the `step` options:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", step: 5)\n```\n\nYou can draw multiple histograms by grouping the observations by a second\n*categorical* variable:\n\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n```\n\nBy default the histograms are plotted layered, but you can also stack them:\n\n```tucan\nTucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5, stacked: true)\n```\n\nor you can facet it, in order to make the histograms more clear:\n\n```tucan\nhistograms =\n  Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", tooltip: true)\n  |> Tucan.facet_by(:column, \"Origin\")\n\nrelative_histograms =\n  Tucan.histogram(:cars, \"Horsepower\", relative: true, color_by: \"Origin\", tooltip: true)\n  |> Tucan.facet_by(:column, \"Origin\")\n\nTucan.vconcat([histograms, relative_histograms])\n```","ref":"Tucan.html#histogram/3-examples"},{"type":"function","title":"Tucan.href_by/2","doc":"Adds a hyperlink encoding.\n\nThe `field` should be the URL that will be loaded upon mouse click.","ref":"Tucan.html#href_by/2"},{"type":"function","title":"Tucan.hruler/3","doc":"Adds a horizontal line at the given `h` position.\n\nFor supported options check `ruler/4`.","ref":"Tucan.html#hruler/3"},{"type":"function","title":"Tucan.imshow/2","doc":"Display data as an image.\n\nThe input is expected to be an `Nx.Tensor` containing 2D scalar data, which will be\nrendered as a pseudo-color image. The origin is set at the upper left hand corner and\nrows (first dimension of the array) are displayed horizontally. By setting `:origin`\nto `:lower` you can set the origin to the lower left hand corner.","ref":"Tucan.html#imshow/2"},{"type":"function","title":"Options - Tucan.imshow/2","doc":"* `:color_scheme` (`t:atom/0`) - The color scheme to be used for the image. Should be one of the supported\n  color schemes of `Tucan.Scale.set_color_scheme/3`. The default value is `:viridis`.\n* `:origin` - Place the `[0, 0]` index of the array in the upper left or lower left corner of the Axes. The\n  convention (the default) `:upper` is typically used for matrices and images.\n\n  Note that the vertical axis points upward for `:lower` but downward for `:upper`.\n\n  ```tucan\n  data = Nx.tensor([[1, 2, 3], [4, 5, 6], [7, 8, 9]], type: {:f, 32})\n\n  Tucan.hconcat([\n    Tucan.imshow(data, width: 200, height: 200, origin: :upper, show_scale: true, tooltip: true)\n    |> Tucan.set_title(\":upper origin (default)\"),\n    Tucan.imshow(data, width: 200, height: 200, origin: :lower, show_scale: true, tooltip: true)\n    |> Tucan.set_title(\":lower origin\")\n  ])\n  ```\n\n  The default value is `:upper`.\n* `:reverse` (`t:boolean/0`) - Whether the color scheme will be reversed or not. The default value is `false`.\n\n#","ref":"Tucan.html#imshow/2-options"},{"type":"function","title":"Styling Options - Tucan.imshow/2","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:show_scale` (`t:boolean/0`) - If set the color scale is displayed. The default value is `false`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#imshow/2-styling-options"},{"type":"function","title":"Interactivity Options - Tucan.imshow/2","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#imshow/2-interactivity-options"},{"type":"function","title":"Examples - Tucan.imshow/2","doc":"> In the following examples we use a subset of the [MNIST dataset](https://en.wikipedia.org/wiki/MNIST_database).\n> The data are stored as a serialized `Nx.Tensor` with shape `{images, height, width, 1}`.\n\n```tucan\nmnist_path = Path.expand(\"../../assets/mnist_sample.bin\", __DIR__)\nimages = File.read!(mnist_path) |> Nx.deserialize()\n\nTucan.imshow(images[[images: 5]], width: 200, height: 200)\n```\n\nBelow we use `Tucan.concat/2` to plot a grid of 40 images of the MNIST dataset. We\nalso set a grayscale color scheme.\n\n```tucan\nmnist_path = Path.expand(\"../../assets/mnist_sample.bin\", __DIR__)\nimages = File.read!(mnist_path) |> Nx.deserialize()\n\nimages =\n  for i <- 1..40 do\n    image = images[[images: i]]\n    Tucan.imshow(image, width: 60, height: 60, color_scheme: :greys, reverse: true)\n  end\n\nTucan.concat(images, columns: 10)\n```\n\nYou can use any of the supported color schemes. Below we draw the same image with 10\ndifferent color schemes with and without `:reverse` set. (Notice how we use `VegaLite.resolve/3`\nto ensure that each sub-plot will have an independent color scale.)\n\n```tucan\nmnist_path = Path.expand(\"../../assets/mnist_sample.bin\", __DIR__)\nimages = File.read!(mnist_path) |> Nx.deserialize()\nimage = images[[images: 2]]\n\nschemes = [:viridis, :inferno, :plasma, :turbo, :greenblue, :darkgold, :rainbow, :redblue, :greens, :greys]\n\nnon_reversed =\n  for scheme <- schemes do\n    Tucan.imshow(image, color_scheme: scheme, width: 60, height: 60, title: Atom.to_string(scheme))\n  end\n\nreversed =\n  for scheme <- schemes do\n    Tucan.imshow(image, color_scheme: scheme, reverse: true, width: 60, height: 60)\n  end\n\nTucan.vconcat([\n  Tucan.hconcat(non_reversed)\n  |> VegaLite.resolve(:scale, color: :independent),\n  Tucan.hconcat(reversed)\n  |> VegaLite.resolve(:scale, color: :independent)\n])\n```\n\n> ##","ref":"Tucan.html#imshow/2-examples"},{"type":"function","title":"3d plots visualization {: .tip} - Tucan.imshow/2","doc":">\n> You can also use `imshow/2` to \"visualize\" 3d plots. Below we create a meshgrid\n> and calculate the value of a function across the grid. We then use `imshow/2` to\n> visualize `z` using the color:\n>\n> ```tucan\n> nx = 121\n> ny = 121\n>\n> x = Nx.linspace(-20, 20, n: nx)\n> y = Nx.linspace(-20, 20, n: ny)\n>\n> defmodule Foo do\n>  import Nx.Defn\n>\n>  defn f(x, y) do\n>    Nx.sqrt(Nx.pow(x - 5, 2) + Nx.pow(y - 5, 2))\n>  end\n>\n>  def meshgrid(x, y, nx, ny) do\n>    xx = Nx.broadcast(x, {ny, nx}, axes: [1])\n>    yy = Nx.broadcast(y, {ny, nx}, axes: [0])\n>\n>    {xx, yy}\n>  end\n> end\n>\n> {xx, yy} = Foo.meshgrid(x, y, nx, ny)\n>\n> zz = Foo.f(xx, yy)\n>\n> Tucan.imshow(zz, width: 300, height: 300, origin: :lower, show_scale: true)\n> ```","ref":"Tucan.html#imshow/2-3d-plots-visualization-tip"},{"type":"function","title":"Tucan.jointplot/4","doc":"Returns the specification of a jointplot.\n\nA jointplot is a plot of two numerical variables along with marginal univariate\ngraphs. If no options are set the joint is a scatter plot and the marginal are\nthe histograms of the two variables.\n\n> ##","ref":"Tucan.html#jointplot/4"},{"type":"function","title":"Marginal plots dimensions {: .info} - Tucan.jointplot/4","doc":">\n> By default a jointplot will have a square shape, e.g. it will have the same\n> width and height. The `:width` option affects the width of the central (joint)\n> plot.\n>\n> For the marginal distributions you can the `:ratio` option which specifies\n> the ratio of joint axes height to marginal axes height.","ref":"Tucan.html#jointplot/4-marginal-plots-dimensions-info"},{"type":"function","title":"Options - Tucan.jointplot/4","doc":"* `:joint` - The plot type to be used for the main (joint) plot. Can be one of\n  `:scatter` and `:density_heatmap`. The default value is `:scatter`.\n* `:joint_opts` (`t:keyword/0`) - Arbitrary options list for the joint plot. The supported options\n  depend on the selected `:joint` type. The default value is `[]`.\n* `:marginal` - The plot type to be used for the marginal plots. Can be one of\n  `:histogram` and `:density`. The default value is `:histogram`.\n* `:marginal_opts` (`t:keyword/0`) - Arbitrary options list for the marginal plots. The supported options\n  depend on the selected `:marginal` type. The default value is `[]`.\n* `:ratio` (`t:float/0`) - The ratio of the marginal plots secondary dimension with respect to\n  the joint plot dimension. The default value is `0.45`.\n\n#","ref":"Tucan.html#jointplot/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.jointplot/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#jointplot/4-data-grouping-options"},{"type":"function","title":"Styling Options - Tucan.jointplot/4","doc":"* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:spacing` (`t:pos_integer/0`) - The spacing between the marginals and the joint plot. The default value is `15`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - The dimension of the central (joint) plot. The same value is used for\n  both the width and height of the plot. The default value is `200`.","ref":"Tucan.html#jointplot/4-styling-options"},{"type":"function","title":"Examples - Tucan.jointplot/4","doc":"A simple joint plot between two variables.\n\n```tucan\nTucan.jointplot(:iris, \"petal_width\", \"petal_length\", width: 200)\n```\n\nYou can also pass `:color_by` to apply a semantic grouping. If set it will be\napplied both to the joint and the marginal plots.\n\n```tucan\nTucan.jointplot(\n  :iris, \"petal_width\", \"petal_length\",\n  color_by: \"species\",\n  fill_opacity: 0.5,\n  width: 200\n)\n```\n\nYou can change the type of the join plot and the marginal distributions:\n\n```tucan\nTucan.jointplot(\n  :penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\",\n  joint: :density_heatmap,\n  marginal: :density,\n  ratio: 0.3\n)\n```","ref":"Tucan.html#jointplot/4-examples"},{"type":"function","title":"Tucan.layers/2","doc":"Creates a layered plot.\n\nThis is a simple wrapper around `VegaLite.layers/2` which by default adds\nthe layers under an empty plot. If a multi-layer plot is passed to `plots`\nthen it's layers will be extracted and merged with the rest layers as long\nas the plot has not a top level data item defined.","ref":"Tucan.html#layers/2"},{"type":"function","title":"Tucan.lineplot/4","doc":"Draw a line plot between `x` and `y`\n\nBoth `x` and `y` are considered numerical variables.","ref":"Tucan.html#lineplot/4"},{"type":"function","title":"Options - Tucan.lineplot/4","doc":"* `:interpolate` (`t:binary/0`) - The line interpolation method to use for line and area marks. One of the following:\n\n  * `\"linear\"` - piecewise linear segments, as in a poly-line.\n  * `\"linear-closed\"` - close the linear segments to form a polygon.\n  * `\"step\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"step-before\"` - alternate between vertical and horizontal segments, as in a step function.\n  * `\"step-after\"` - alternate between horizontal and vertical segments, as in a step function.\n  * `\"basis\"` - a B-spline, with control point duplication on the ends.\n  * `\"basis-open\"` - an open B-spline; may not intersect the start or end.\n  * `\"basis-closed\"` - a closed B-spline, as in a loop.\n  * `\"cardinal\"` - a Cardinal spline, with control point duplication on the ends.\n  * `\"cardinal-open\"` - an open Cardinal spline; may not intersect the start or end, but will\n  intersect other control points.\n  * `\"cardinal-closed\"` - a closed Cardinal spline, as in a loop.\n  * `\"bundle\"` - equivalent to basis, except the tension parameter is used to straighten the spline.\n  * `\"monotone\"` - cubic interpolation that preserves monotonicity in y.\n* `:tension` (`t:number/0`) - Depending on the interpolation type, sets the tension parameter\n\n#","ref":"Tucan.html#lineplot/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.lineplot/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A field to group by the lines without affecting the style of it.\n\n#","ref":"Tucan.html#lineplot/4-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.lineplot/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#lineplot/4-data-options"},{"type":"function","title":"Styling Options - Tucan.lineplot/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:filled` (`t:boolean/0`) - Whether the points will be filled or not. Valid only if `:points` is set. The default value is `true`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:point_color` (`t:String.t/0`) - The color of the points, if `:points` is set to `true`.\n* `:points` (`t:boolean/0`) - Whether points will be included in the chart. The default value is `false`.\n* `:stroke_dash` (list of `t:pos_integer/0`) - An array of alternating stroke, space lengths in pixels for creating dashed\n  or dotted lines.\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#lineplot/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.lineplot/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#lineplot/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.lineplot/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#lineplot/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.lineplot/4","doc":"Plotting a simple line chart of Google stock price over time. Notice how we change the\n`x` axis type from the default (`:quantitative`) to `:temporal` using the generic\n`:x` channel configuration option:\n\n```tucan\nTucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal])\n|> VegaLite.transform(filter: \"datum.symbol==='GOOG'\")\n```\n\nYou could plot all stocks of the dataset with different colors by setting the `:color_by`\noption. If you do not want to color lines differently, you can pass the `:group_by` option\ninstead of `:color_by`:\n\n```tucan\nleft = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], color_by: \"symbol\")\nright = Tucan.lineplot(:stocks, \"date\", \"price\", x: [type: :temporal], group_by: \"symbol\")\n\nTucan.hconcat([left, right])\n```\n\nYou can also overlay the points by setting the `:points` and `:filled` opts. Notice\nthat below we plot by year and aggregating the `y` values:\n\n```tucan\nfilled_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    tooltip: true,\n    width: 300\n  )\n\nstroked_points =\n  Tucan.lineplot(:stocks, \"date\", \"price\",\n    x: [type: :temporal, time_unit: :year],\n    y: [aggregate: :mean],\n    color_by: \"symbol\",\n    points: true,\n    filled: false,\n    tooltip: true,\n    width: 300\n  )\n\nTucan.hconcat([filled_points, stroked_points])\n```\n\nYou can configure the style of the lines using `:stroke_dash`, `:stroke_width`\nand `:line_color` options.\n\n```tucan\ndata =\n  for i <- 0..100, x = 0.1*i do\n    %{x: x, cos: :math.cos(x), sin: :math.sin(x)}\n  end\n\nTucan.layers([\n  Tucan.lineplot(data, \"x\", \"cos\", stroke_width: 3, stroke_dash: [5, 2], line_color: \"red\"),\n  Tucan.lineplot(data, \"x\", \"sin\", stroke_width: 2, stroke_dash: [5, 3, 2], line_color: \"green\")\n])\n|> Tucan.set_width(300)\n```\n\nYou can use various interpolation methods. Some examples follow:\n\n```tucan\nplots =\n  for interpolation <- [\"linear\", \"step\", \"cardinal\", \"monotone\"] do\n    Tucan.lineplot(:stocks, \"date\", \"price\",\n      x: [type: :temporal, time_unit: :year],\n      y: [aggregate: :mean],\n      color_by: \"symbol\",\n      interpolate: interpolation\n    )\n    |> Tucan.set_title(interpolation)\n  end\n\nTucan.concat(plots, columns: 2)\n```","ref":"Tucan.html#lineplot/4-examples"},{"type":"function","title":"Tucan.lollipop/4","doc":"Draws a lollipop plot.\n\nA lollipop plot is nothing more than a bar plot, where the bar is transformed in a line and a dot. It shows\nthe relationship between a numeric and a categoric variable.\n\n> ##","ref":"Tucan.html#lollipop/4"},{"type":"function","title":"Comparison to `bar/4` {: .tip} - Tucan.lollipop/4","doc":">\n> The lollipop plot is used exactly in the same situation as a bar plot. However it is somewhat more\n> appealing and convey as well the information. It is especially useful when you have several bars of the\n> same height.\n>\n> ```tucan\n> data = [\n>   category: [\"A\", \"B\", \"C\", \"D\", \"E\"],\n>   value: [99, 97, 94, 90, 88]\n> ]\n>\n> bar = Tucan.bar(data, \"category\", \"value\", orient: :horizontal)\n> lollipop = Tucan.lollipop(data, \"category\", \"value\", orient: :horizontal)\n>\n> Tucan.hconcat([bar, lollipop])\n> ```\n\nSee also `bar/4`.","ref":"Tucan.html#lollipop/4-comparison-to-bar-4-tip"},{"type":"function","title":"Options - Tucan.lollipop/4","doc":"#","ref":"Tucan.html#lollipop/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.lollipop/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:group_by` (`t:String.t/0`) - A categorical field to group the lollipops by. It is used for adding a second dimension to\n  the plot. When set, the groups are also color coded by the same categorical variable.\n\n#","ref":"Tucan.html#lollipop/4-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.lollipop/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#lollipop/4-data-options"},{"type":"function","title":"Styling Options - Tucan.lollipop/4","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:line_color` (`t:String.t/0`) - The color of the line The default value is `\"black\"`.\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:vertical`.\n* `:point_color` (`t:String.t/0`) - The color of the points The default value is `\"black\"`.\n* `:point_shape` - Shape of the point marks. Circle by default.\n* `:point_size` (`t:pos_integer/0`) - The pixel area of the marks. Note that this value sets the area of the symbol;\n  the side lengths will increase with the square root of this value. The default value is `60`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#lollipop/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.lollipop/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:x_offset` (`t:keyword/0`) - Extra vega lite options for the `:x_offset` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#lollipop/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.lollipop/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#lollipop/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.lollipop/4","doc":"A lollipop chart for some synthetic data:\n\n```tucan\ndata =\n  for category <- [\"A\", \"B\", \"C\", \"D\", \"E\", \"F\", \"G\", \"H\", \"I\", \"J\"] do\n    %{category: category, value: 9 + :rand.uniform(90)}\n  end\n\nTucan.lollipop(data, \"category\", \"value\", width: 400)\n```\n\nYou can make the lollipops horizontal by setting the `:orient` flag:\n\n```tucan\ndata =\n  for category <- [\"A\", \"B\", \"C\", \"D\", \"E\", \"F\", \"G\", \"H\", \"I\", \"J\"] do\n    %{category: category, value: 9 + :rand.uniform(90)}\n  end\n\nTucan.lollipop(data, \"category\", \"value\", width: 400, orient: :horizontal)\n```\n\nYou can change the points shape and the default colors if needed:\n\n```tucan\ndata =\n  for category <- [\"A\", \"B\", \"C\", \"D\", \"E\", \"F\", \"G\", \"H\", \"I\", \"J\"] do\n    %{category: category, value: 9 + :rand.uniform(90)}\n  end\n\nTucan.lollipop(data, \"category\", \"value\",\n  point_color: \"red\",\n  point_shape: \"square\",\n  point_size: 80,\n  line_color: \"blue\",\n  width: 400\n)\n```\n\nIf you need to group by a second categorical variable you can use the `:group_by` option:\n\n```tucan\ndata =\n  for category <- [\"A\", \"B\", \"C\", \"D\", \"E\", \"F\", \"G\"],\n      country <- [\"US\", \"GR\", \"UK\", \"IT\"] do\n    %{category: category, country: country, value: 9 + :rand.uniform(90)}\n  end\n\nTucan.lollipop(data, \"category\", \"value\", group_by: \"country\", orient: :horizontal)\n|> Tucan.set_size(400, 300)\n```","ref":"Tucan.html#lollipop/4-examples"},{"type":"function","title":"Tucan.new/0","doc":"Creates an empty `VegaLite` plot.\n\nThis is a simple wrapper around `VegaLite.new/0`.","ref":"Tucan.html#new/0"},{"type":"function","title":"Tucan.new/2","doc":"Creates if needed a `VegaLite` plot and adds data to it.\n\nThe behaviour of this function depends on the type of `plotdata`:\n\n* if a `VegaLite.t()` struct is passed then it is returned unchanged.\n* If it is a binary it is considered a url and the `VegaLite.data_from_url/2` is\n  called on a newly created `VegaLite` struct.\n* if it is an atom then it is considered a `Tucan.Dataset` and it is translated to\n  the dataset's url. If the dataset name is invalid an exception is raised.\n* in any other case it is considered a set of data values and the values are set\n  as data to a newly created `VegaLite` struct. Any tabular data is accepted, as\n  long as it adheres to the `Table.Reader` protocol.","ref":"Tucan.html#new/2"},{"type":"function","title":"Examples - Tucan.new/2","doc":"Passing a URL to some dataset\n\n```elixir\nTucan.new(\"https://vega.github.io/editor/data/penguins.json\")\n|> ...\n\nTucan.new(\"https://vega.github.io/editor/data/stocks.csv\", format: :csv)\n|> ...\n```\n\nUsing a pre-defined `Tucan.Dataset`\n\n```elixir\nTucan.new(:penguins)\n|> ...\n\nTucan.new(:iris)\n|> ...\n```\n\nPassing directly tabular data\n\n```elixir\ndata = [\n  %{\"category\" => \"A\", \"score\" => 28},\n  %{\"category\" => \"B\", \"score\" => 55}\n]\n\nTucan.new(data)\n|> ...\n```\n\nYou can also pass individual series:\n\n```elixir\nxs = 1..100\nys = 1..100\n\nTucan.new(x: xs, y: ys)\n|> ...\n```\n\nAny data that adheres to the `Table.Reader` protocol is accepted, for example\nyou could pass an [`Explorer.DataFrame`](https://hexdocs.pm/explorer/Explorer.DataFrame.html)\n\n```elixir\nmountains = Explorer.DataFrame.new(\n  name: [\"Everest\", \"K2\", \"Aconcagua\"],\n  elevation: [8848, 8611, 6962]\n)\n\nTucan.new(mountains)\n|> ...\n```\n\nAdditionally you can pass `Nx.Tensor`s as series. These will be implicitly\ntransformed to lists.\n\n```elixir\nxs = Nx.linspace(0, 10, n: 100)\nys = Nx.sin(xs)\n\nTucan.new([x: xs, y: ys])\n|> ...\n```\n\n> ##","ref":"Tucan.html#new/2-examples"},{"type":"function","title":"Valid `Nx.Tensor` shapes {: .info} - Tucan.new/2","doc":">\n> 1-dimensional tensors are expected when you pass `Nx` tensors as series.\n> Additionally for convenience 2-dimensional tensors where one of the two\n> dimensions is `1` are also supported.\n>\n> For example the following are equivalent\n>\n> ```elixir\n> x = Nx.linspace(0, 10, n: 10)\n> y = Nx.pow(x, 2)\n>\n> plot1 = Tucan.new(x: x, y: y)\n>\n> x = Nx.reshape(x, {10, 1})\n> y = Nx.reshape(y, {1, 10})\n>\n> plot2 = Tucan.new(x: x, y: y)\n>\n> assert plot1 == plot2\n> ```\n>\n> For all other tensor shapes an `ArgumentError` will be raised.","ref":"Tucan.html#new/2-valid-nx-tensor-shapes-info"},{"type":"function","title":"Tucan.pairplot/3","doc":"Plot pairwise relationships in a dataset.\n\nThis function expects an array of fields to be provided. A grid will be created\nwhere each numeric variable in `fields` will be shared across the y-axes across\na single row and the x-axes across a single column.\n\n> ##","ref":"Tucan.html#pairplot/3"},{"type":"function","title":"Numerical field types {: .warning} - Tucan.pairplot/3","doc":">\n> Notice that currently `pairplot/3` works only with numerical (`:quantitative`)\n> variables. If you need to create a pair plot containing other variable types\n> you need to manually build the grid using the `VegaLite` concatenation operations.","ref":"Tucan.html#pairplot/3-numerical-field-types-warning"},{"type":"function","title":"Options - Tucan.pairplot/3","doc":"* `:diagonal` - The plot type to be used for the diagonal subplots. Can be one on\n  `:scatter`, `:density` and `:histogram`. The default value is `:scatter`.\n* `:plot_fn` (function of arity 3) - An optional function for customizing the look any subplot. It expects a\n  function with the following signature:\n\n  ```elixir\n  (vl :: VegaLite.t(), row :: {String.t(), integer()}, column :: {String.t(), integer()})\n    :: VegaLite.t()\n  ```\n\n  where both `row` and `column` are tuples containing the index and field of\n  the current and row and column respectively.\n\n  You are free to specify any function for every cell of the grid.\n\n#","ref":"Tucan.html#pairplot/3-options"},{"type":"function","title":"Data Options - Tucan.pairplot/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#pairplot/3-data-options"},{"type":"function","title":"Styling Options - Tucan.pairplot/3","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\nNotice that if set `width` and `height` will be applied to individual sub plots. On\nthe other hand `title` is applied to the composite plot.","ref":"Tucan.html#pairplot/3-styling-options"},{"type":"function","title":"Examples - Tucan.pairplot/3","doc":"By default a scatter plot will be drawn for all pairwise plots:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n```\n\nYou can color the points by another field in to add some semantic mapping. Notice\nthat you need the `recursive` option to `true` for the grouping to be applied on all\ninternal subplots.\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nBy specifying the `:diagonal` option you can change the default plot for the diagonal\nelements to a histogram:\n\n```tucan\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, fields, width: 130, height: 130, diagonal: :histogram)\n|> Tucan.color_by(\"species\", recursive: true)\n```\n\nAdditionally you have the option to configure a `plot_fn` with which we can go crazy and\nmodify any part of the grid based on our needs. `plot_fn` should accept as input a `VegaLite`\nstruct and two tuples containing the row and column fields and indexes. In the following\nexample we draw differently the diagonal, the lower and the upper grid. Notice that we don't\ncall `color_by/3` since we color differently the plots based on their index positions.\n\n```tucan\nTucan.pairplot(:iris, [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"],\n  width: 150,\n  height: 150,\n  plot_fn: fn vl, {row_field, row_index}, {col_field, col_index} ->\n    cond do\n      # For the first two diagonal elements we plot a histogram, no\n      row_index == col_index and row_index < 2 ->\n        Tucan.histogram(vl, row_field)\n\n      row_index == 2 and col_index == 2 ->\n        Tucan.stripplot(vl, row_field, group_by: \"species\", style: :tick)\n        |> Tucan.color_by(\"species\")\n        |> Tucan.Axes.put_options(:y, labels: false)\n\n      # For the other diagonal plots we plot a histogram colored_by the species\n      row_index == col_index ->\n        Tucan.histogram(vl, row_field, color_by: \"species\")\n\n      # For the upper part of the diagram we apply a scatter plot\n      row_index  \n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.color_by(\"species\")\n\n      # for anything else scatter plot with a quantitative color scale\n      # and size\n      true ->\n        Tucan.scatter(vl, col_field, row_field)\n        |> Tucan.size_by(\"petal_width\", type: :quantitative)\n\n    end\n  end\n)\n```","ref":"Tucan.html#pairplot/3-examples"},{"type":"function","title":"Tucan.pie/4","doc":"Draws a pie chart.\n\nA pie chart is a circle divided into sectors that each represents a proportion\nof the whole. The `field` specifies the data column that contains the proportions\nof each category. The chart will be colored by the `category` field.\n\n> ##","ref":"Tucan.html#pie/4"},{"type":"function","title":"Avoid using pie charts {: .warning} - Tucan.pie/4","doc":">\n> Despite it's popularity pie charts should rarely be used. Pie charts are best\n> suited for displaying a small number of categories and can make it challenging\n> to accurately compare data. They rely on angle perception, which can lead to\n> misinterpretation, and lack the precision offered by other charts like bar\n> charts or line charts.\n>\n> Instead, opt for alternatives such as bar charts for straightforward comparisons,\n> stacked area charts for cumulative effects.\n>\n> The following example showcases the limitations of a pie chart, compared to a\n> bar chart:\n>\n> ```tucan\n> alias VegaLite, as: Vl\n>\n> data = [\n>   %{value: 30, category: \"A\"},\n>   %{value: 33, category: \"B\"},\n>   %{value: 38, category: \"C\"}\n> ]\n>\n> pie = Tucan.pie(data, \"value\", \"category\")\n> bar = Tucan.bar(data, \"category\", \"value\", orient: :horizontal)\n>\n> Tucan.hconcat([pie, bar])\n> |> Tucan.set_title(\"Pie vs Bar chart\", anchor: :middle, offset: 15)\n> ```","ref":"Tucan.html#pie/4-avoid-using-pie-charts-warning"},{"type":"function","title":"Options - Tucan.pie/4","doc":"* `:aggregate` (`t:atom/0`) - The statistic to use (if any) for aggregating values per pie slice (e.g. `:mean`).\n* `:inner_radius` (`t:integer/0`) - The inner radius in pixels. `0` for a pie chart, `> 0` for a donut chart. If not\n  set it defaults to 0\n\n#","ref":"Tucan.html#pie/4-options"},{"type":"function","title":"Data Options - Tucan.pie/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#pie/4-data-options"},{"type":"function","title":"Styling Options - Tucan.pie/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#pie/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.pie/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:theta` (`t:keyword/0`) - Extra vega lite options for the `:theta` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#pie/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.pie/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#pie/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.pie/4","doc":"```tucan\nTucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n|> Tucan.facet_by(:column, \"year\", type: :nominal)\n```","ref":"Tucan.html#pie/4-examples"},{"type":"function","title":"Tucan.punchcard/5","doc":"Returns the specification of a punch card plot.\n\nA punch card plot is similar to a heatmap but instead of color the third\ndimension is encoded by the size of bubbles.\n\nSee also `heatmap/5`.","ref":"Tucan.html#punchcard/5"},{"type":"function","title":"Options - Tucan.punchcard/5","doc":"* `:aggregate` (`t:atom/0`) - The statistic that will be used for aggregating the observations within a heatmap\n  tile. Defaults to `:mean` which in case of single data will encode the value of\n  the `color` data field.\n\n  Ignored if `:color` is set to `nil`.\n* `:annotate` (`t:boolean/0`) - If set to `true` then the values of each cell will be included in the plot. The default value is `false`.\n\n#","ref":"Tucan.html#punchcard/5-options"},{"type":"function","title":"Data Options - Tucan.punchcard/5","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#punchcard/5-data-options"},{"type":"function","title":"Styling Options - Tucan.punchcard/5","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:color_scheme` (`t:atom/0`) - The color scheme to use, for supported color schemes check `Tucan.Scale`. Notice that\n  this is just a helper option for easily setting color schemes. If you need to set\n  specific colors or customize the scheme, use `Tucan.Scale.set_color_scheme/3`.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:text_color` - The color to be used for the textual annotations. Valid only if `:annotate` is set\n  to `true`. Can be one of the following:\n  * a `string` with the color to be used, e.g. `\"white\"`\n  * a list of tuples of the form `{low_threshold, upper_threshold, color}` for\n  conditionally setting the color based on the value of the annotated variable.\n  `low_threshold` and `upper_threshold` can either be a number or `nil`. For example\n  `[{nil, 0, \"green\"}, {0, 5, \"red\"}, {5, nil, \"white\"}]` will apply the following\n  colors:\n    * `green` for all items with `value < 0`\n    * `red` for all items with `value >= 0 && value < 5`\n    * `white` for all items with `value >= 5`\n  Notice that the `low_threshold`, `upper_threshold` correspond to the\n  `[low_threshold, upper_threshold)` range.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#punchcard/5-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.punchcard/5","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#punchcard/5-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.punchcard/5","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#punchcard/5-interactivity-options"},{"type":"function","title":"Examples - Tucan.punchcard/5","doc":"```tucan\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.set_title(\"Punch card of Avg Max Temperatures in Seattle (2012-2015)\")\n```\n\nYou can add a fourth dimension by coloring the plot by a fourth variable. Notice how\nwe use `Tucan.Scale.set_color_scheme/3` to apply a semantically reasonable coloring and\n`Tucan.Legend.set_orientation/3` to change the default position of the two legends.\n\n```tucan\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  tooltip: true,\n  x: [type: :ordinal, time_unit: :date],\n  y: [type: :ordinal, time_unit: :month]\n)\n# we need to set recursive to true since this is a layered plot\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:size, \"bottom\")\n```","ref":"Tucan.html#punchcard/5-examples"},{"type":"function","title":"Tucan.ruler/4","doc":"Adds a vertical or horizontal ruler at the given position.\n\n`position` can either be a number representing a coordinate of the _x/y-axis_ or a\nbinary representing a field. In the latter case an aggregation can also\nbe provided which will be used for aggregating the field distribution\nto a single number. If not set defaults to `:mean`.\n\n`axis` specifies the orientation of the line. Use `:x` for a vertical\nline and `:y` for a horizontal one.\n\nSee also `vruler/3`, `hruler/3`.","ref":"Tucan.html#ruler/4"},{"type":"function","title":"Options - Tucan.ruler/4","doc":"* `:aggregate` (`t:atom/0`) - The aggregate to used for calculating the line's coordinate The default value is `:mean`.\n* `:line_color` - The default value is `\"black\"`.\n\n#","ref":"Tucan.html#ruler/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.ruler/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#ruler/4-data-grouping-options"},{"type":"function","title":"Styling Options - Tucan.ruler/4","doc":"* `:stroke_dash` (list of `t:pos_integer/0`) - An array of alternating stroke, space lengths in pixels for creating dashed\n  or dotted lines.\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels The default value is `1`.\n\n#","ref":"Tucan.html#ruler/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.ruler/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.","ref":"Tucan.html#ruler/4-encodings-custom-options"},{"type":"function","title":"Examples - Tucan.ruler/4","doc":"You can add a vertical ruler to any _x-axis_ point:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.ruler(:x, 1.1, stroke_width: 3, line_color: \"blue\")\n|> Tucan.ruler(:x, 1.4, line_color: \"green\")\n```\n\nAdditionally you can can add a vertical line to an aggregated value of\na data field. For example:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.ruler(:x, \"petal_width\", line_color: \"red\")\n```\n\nYou can add multiple lines for each group of the data if you pass the\n`color_by` option. Also you can combine vertical with horizontal\nlines.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.ruler(:x, \"petal_width\", color_by: \"species\", stroke_width: 3)\n|> Tucan.ruler(:y, \"petal_length\", color_by: \"species\", stroke_dash: [5, 5])\n```","ref":"Tucan.html#ruler/4-examples"},{"type":"function","title":"Tucan.scatter/4","doc":"Returns the specification of a scatter plot with possibility of several semantic\ngroupings.\n\nBoth `x` and `y` must be `:quantitative`.\n\n> ##","ref":"Tucan.html#scatter/4"},{"type":"function","title":"Semantic groupings {: .tip} - Tucan.scatter/4","doc":">\n> The relationship between `x` and `y` can be shown for different subsets of the\n> data using the `color_by`, `size_by` and `shape_by` parameters. This is equivalent\n> to calling the corresponding functions after a `scatter/4` call.\n>\n> These parameters control what visual semantics are used to identify the different\n> subsets. It is possible to show up to three dimensions independently by using all\n> three semantic types, but this style of plot can be hard to interpret and is often\n> ineffective.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"sex\",\n>   size_by: \"size\"\n> )\n> ```\n>\n> The above is equivalent to calling:\n>\n> ```elixir\n> Tucan.scatter(:tips, \"total_bill\", \"tip\")\n> |> Tucan.color_by(\"day\", type: :nominal)\n> |> Tucan.shape_by(\"sex\", type: :nominal)\n> |> Tucan.size_by(\"size\", type: :quantitative)\n> ```\n>\n> Using redundant semantics (i.e. both color and shape for the same variable) can be\n> helpful for making graphics more accessible.\n>\n> ```tucan\n> Tucan.scatter(:tips, \"total_bill\", \"tip\",\n>   color_by: \"day\",\n>   shape_by: \"day\"\n> )\n> ```","ref":"Tucan.html#scatter/4-semantic-groupings-tip"},{"type":"function","title":"Options - Tucan.scatter/4","doc":"#","ref":"Tucan.html#scatter/4-options"},{"type":"function","title":"Data Grouping Options - Tucan.scatter/4","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n* `:shape_by` (`t:String.t/0`) - If set a data field that will be used for setting the shape of the data points.\n  It is considered `:nominal` by default.\n* `:size_by` (`t:String.t/0`) - If set a data field that will be used for controlling the size of the data points.\n  It is considered `:quantitative` by default.\n\n#","ref":"Tucan.html#scatter/4-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.scatter/4","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#scatter/4-data-options"},{"type":"function","title":"Styling Options - Tucan.scatter/4","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:filled` (`t:boolean/0`) - Whether the mark will be filled or not\n* `:height` (`t:integer/0`) - Height of the image\n* `:point_color` (`t:String.t/0`) - The color of the points\n* `:point_shape` - Shape of the point marks. Circle by default.\n* `:point_size` (`t:pos_integer/0`) - The pixel area of the marks. Note that this value sets the area of the symbol;\n  the side lengths will increase with the square root of this value.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#scatter/4-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.scatter/4","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:shape` (`t:keyword/0`) - Extra vega lite options for the `:shape` encoding. The default value is `[]`.\n* `:size` (`t:keyword/0`) - Extra vega lite options for the `:size` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#scatter/4-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.scatter/4","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#scatter/4-interactivity-options"},{"type":"function","title":"Examples - Tucan.scatter/4","doc":"> We will use the `:tips` dataset throughout the following examples.\n\nDrawing a scatter plot between two variables:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n```\n\nYou can modify the look of the plot by setting various styling options:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\",\n  point_color: \"red\",\n  point_shape: \"triangle-up\",\n  point_size: 10\n)\n```\n\nYou can combine it with `color_by/3` to color code the points with respect to\nanother variable:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\")\n|> Tucan.color_by(\"time\")\n```\n\nAssigning the same variable to `shape_by/3` will also vary the markers and create a\nmore accessible plot:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"time\")\n|> Tucan.shape_by(\"time\")\n```\n\nAssigning `color_by/3` and `shape_by/3` to different variables will vary colors and\nmarkers independently:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"time\")\n```\n\nYou can also color the points by a numeric variable, the semantic mapping will be\nquantitative and will use a different default palette:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400)\n|> Tucan.color_by(\"size\", type: :quantitative)\n```\n\nA numeric variable can also be assigned to size to apply a semantic mapping to the\nareas of the points:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 400, tooltip: :data)\n|> Tucan.color_by(\"size\", type: :quantitative)\n|> Tucan.size_by(\"size\", type: :quantitative)\n```\n\nYou can also combine it with `facet_by/3` in order to group within additional\ncategorical variables, and plot them across multiple subplots.\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.facet_by(:column, \"time\")\n```\n\nYou can also apply faceting on more than one variables, both horizontally and\nvertically:\n\n```tucan\nTucan.scatter(:tips, \"total_bill\", \"tip\", width: 300)\n|> Tucan.color_by(\"day\")\n|> Tucan.shape_by(\"day\")\n|> Tucan.size_by(\"size\")\n|> Tucan.facet_by(:column, \"time\")\n|> Tucan.facet_by(:row, \"sex\")\n```","ref":"Tucan.html#scatter/4-examples"},{"type":"function","title":"Tucan.set_height/2","doc":"Sets the height of the plot (in pixels).","ref":"Tucan.html#set_height/2"},{"type":"function","title":"Tucan.set_size/3","doc":"Sets the plot size.\n\nThis sets both width and height at once.","ref":"Tucan.html#set_size/3"},{"type":"function","title":"Tucan.set_theme/2","doc":"Sets the plot's theme.\n\nCheck `Tucan.Themes` for more details on theming.","ref":"Tucan.html#set_theme/2"},{"type":"function","title":"Tucan.set_title/3","doc":"Sets the title of the plot.\n\nYou can optionally pass any title option supported by vega-lite to customize the\nstyle of it.","ref":"Tucan.html#set_title/3"},{"type":"function","title":"Examples - Tucan.set_title/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.set_title(\"My awesome plot\",\n    color: \"red\",\n    subtitle: \"with a subtitle\",\n    subtitle_color: \"green\",\n    anchor: \"start\"\n  )\n```\n\nIf you need to set a multi-line title you can pass a multiline string.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.set_title(\"My multiline\\ntitle\")\n```","ref":"Tucan.html#set_title/3-examples"},{"type":"function","title":"Tucan.set_width/2","doc":"Sets the width of the plot (in pixels).","ref":"Tucan.html#set_width/2"},{"type":"function","title":"Tucan.shape_by/3","doc":"Adds a `shape` encoding for the given field.","ref":"Tucan.html#shape_by/3"},{"type":"function","title":"Options - Tucan.shape_by/3","doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#shape_by/3-options"},{"type":"function","title":"Tucan.size_by/3","doc":"Adds a `size` encoding for the given field.\n\nBy default the type of the `field` is set to `:quantitative`. You can override it in the\n`opts` by setting another `:type`.","ref":"Tucan.html#size_by/3"},{"type":"function","title":"Options - Tucan.size_by/3","doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#size_by/3-options"},{"type":"function","title":"Tucan.step/4","doc":"Returns the specification of a step chart.\n\nThis is a simple wrapper around `lineplot/4` with `:interpolate` set by default\nto `\"step\"`. If `:interpolate` is set to any of `step, step-before, step-after` it\nwill be used. In any other case defaults to `step`.","ref":"Tucan.html#step/4"},{"type":"function","title":"Options - Tucan.step/4","doc":"Check `lineplot/4`","ref":"Tucan.html#step/4-options"},{"type":"function","title":"Examples - Tucan.step/4","doc":"```tucan\nTucan.step(:stocks, \"date\", \"price\", color_by: \"symbol\", width: 300, x: [type: :temporal])\n|> Tucan.Scale.set_y_scale(:log)\n```","ref":"Tucan.html#step/4-examples"},{"type":"function","title":"Tucan.streamgraph/5","doc":"Returns the specification of a streamgraph.\n\nThis is a simple wrapper around `area/4` with `:mode` set by default\nto `:streamgraph`. Any value set to the `:mode` option will be ignored.\n\nA grouping field must also be provided which will be set as `:color_by` to\nthe area chart.","ref":"Tucan.html#streamgraph/5"},{"type":"function","title":"Options - Tucan.streamgraph/5","doc":"Check `area/4`","ref":"Tucan.html#streamgraph/5-options"},{"type":"function","title":"Examples - Tucan.streamgraph/5","doc":"```tucan\nTucan.streamgraph(:stocks, \"date\", \"price\", \"symbol\",\n  width: 300,\n  x: [type: :temporal],\n  tooltip: true\n)\n```","ref":"Tucan.html#streamgraph/5-examples"},{"type":"function","title":"Tucan.stripplot/3","doc":"Draws a strip plot (categorical scatterplot).\n\nA strip plot is a single-axis scatter plot used to visualize the distribution of\na numerical field. The values are plotted as dots or ticks along one axis, so\nthe dots with the same value may overlap.\n\nYou can use the `:jitter` mode for a better view of overlapping points. In this\ncase points are randomly shifted along with other axis, which has no meaning in\nitself data-wise.\n\nTypically several strip plots are placed side by side to compare the distribution\nof a numerical value among several categories.","ref":"Tucan.html#stripplot/3"},{"type":"function","title":"Options - Tucan.stripplot/3","doc":"* `:group_by` (`t:String.t/0`) - A field to be used for grouping the strip plot. If not set the plot will\n  be one dimensional.\n* `:jitter_mode` - The distribution from which the jitter (random offset) will be generated. One of\n  `:uniform`, `:normal`. Applicable only when the `:style` is set to `:jitter`. The default value is `:normal`.\n* `:style` - The style of the plot. Can be one of the following:\n    * `:tick` - use ticks for each data point\n    * `:point` - use points for each data point\n    * `:jitter` - use points but also apply some jittering across the other\n    axis\n\n  Use `:jitter` in case of many data points in order to avoid overlaps.\n\n  The default value is `:tick`.\n\n#","ref":"Tucan.html#stripplot/3-options"},{"type":"function","title":"Data Grouping Options - Tucan.stripplot/3","doc":"* `:color_by` (`t:String.t/0`) - If set a data field that will be used for coloring the data. It is considered\n  `:nominal` by default.\n\n#","ref":"Tucan.html#stripplot/3-data-grouping-options"},{"type":"function","title":"Data Options - Tucan.stripplot/3","doc":"* `:only` - A subset of fields to pick from the data. Applicable only if tabular data\n  are provided.\n\n#","ref":"Tucan.html#stripplot/3-data-options"},{"type":"function","title":"Styling Options - Tucan.stripplot/3","doc":"* `:clip` (`t:boolean/0`) - Whether a mark will be clipped to the enclosing group’s width and height.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:height` (`t:integer/0`) - Height of the image\n* `:orient` (`t:atom/0`) - The plot's orientation, can be either `:horizontal` or `:vertical`. The default value is `:horizontal`.\n* `:point_color` (`t:String.t/0`) - The color of the points\n* `:point_shape` - Shape of the point marks. Circle by default.\n* `:point_size` (`t:pos_integer/0`) - The pixel area of the marks. Note that this value sets the area of the symbol;\n  the side lengths will increase with the square root of this value. The default value is `16`.\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image\n\n#","ref":"Tucan.html#stripplot/3-styling-options"},{"type":"function","title":"Encodings Custom Options - Tucan.stripplot/3","doc":"All Tucan plots are building a `VegaLite` specification based on some sane\ndefault parameters. Through these encodings options you are free to set any\nvega-lite supported option to any encoding channel of the plot.\n\nNotice that if set they will be merged with any option set by the plot. Since they\nhave a higher precedence they may override the default settings and affect the\ngenerated plot.\n\nYou can set an arbitrary keyword list. Notice that **the contents are not validated.**\n\n\n* `:color` (`t:keyword/0`) - Extra vega lite options for the `:color` encoding. The default value is `[]`.\n* `:x` (`t:keyword/0`) - Extra vega lite options for the `:x` encoding. The default value is `[]`.\n* `:y` (`t:keyword/0`) - Extra vega lite options for the `:y` encoding. The default value is `[]`.\n* `:y_offset` (`t:keyword/0`) - Extra vega lite options for the `:y_offset` encoding. The default value is `[]`.\n\n#","ref":"Tucan.html#stripplot/3-encodings-custom-options"},{"type":"function","title":"Interactivity Options - Tucan.stripplot/3","doc":"* `:tooltip` (`boolean() | :data | :encoding`) - The tooltip text string to show upon mouse hover or an object defining which fields\n  should the tooltip be derived from. Can be one of the following:\n\n  * `:encoding` - all fields from encoding are used\n  * `:data` - all fields of the highlighted data point are used\n  * `true` - same as `:encoding`\n  * `false`, `nil` - no tooltip is used","ref":"Tucan.html#stripplot/3-interactivity-options"},{"type":"function","title":"Examples - Tucan.stripplot/3","doc":"Assigning a single numeric variable shows the univariate distribution. The default\nstyle is the `:tick`:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\")\n```\n\nFor very dense distribution it makes more sense to use the `:jitter` style in order\nto reduce overlapping points:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", style: :jitter, height: 30, width: 300)\n```\n\nYou can set the `:group_by` option in order to add a second dimension. Notice that\nthe field must be categorical.\n\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter)\n```\n\nThe plot would be more clear if you also colored the points with the same field:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter)\n|> Tucan.color_by(\"day\")\n```\n\nYou can use `:uniform` distribution instead of the default (`:normal`). Below\nyou can see both side by side:\n\n```tucan\nnormal =\n  Tucan.stripplot(:movies, \"IMDB Rating\",\n    group_by: \"Major Genre\",\n    style: :jitter,\n    point_size: 2,\n    width: 300\n  )\n  |> Tucan.color_by(\"Major Genre\", type: :nominal)\n  |> Tucan.set_title(\"Gaussian jittering\")\n  |> Tucan.Legend.set_enabled(:color, false)\n\nuniform =\n  Tucan.stripplot(:movies, \"IMDB Rating\",\n    group_by: \"Major Genre\",\n    style: :jitter,\n    jitter_mode: :uniform,\n    point_size: 2,\n    width: 300\n  )\n  |> Tucan.color_by(\"Major Genre\", type: :nominal)\n  |> Tucan.set_title(\"Uniform jittering\")\n  |> Tucan.Legend.set_enabled(:color, false)\n  |> Tucan.Axes.set_enabled(:y, false)\n\nTucan.hconcat([normal, uniform])\n|> VegaLite.resolve(:scale, y_offset: :independent, y: :shared)\n```\n\nYou can also color by a distinct variable to show a multi-dimensional relationship:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter)\n|> Tucan.color_by(\"sex\")\n```\n\nor you can color by a numerical variable:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter)\n|> Tucan.color_by(\"size\", type: :ordinal)\n```\n\nYou could draw the same with points but without jittering:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :point)\n|> Tucan.color_by(\"sex\")\n```\n\nor with ticks which is the default one:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :tick)\n|> Tucan.color_by(\"sex\")\n```\n\nYou can set the `:orient` flag to `:vertical` to change the orientation:\n\n```tucan\nTucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter, orient: :vertical)\n|> Tucan.color_by(\"sex\")\n```","ref":"Tucan.html#stripplot/3-examples"},{"type":"function","title":"Tucan.stroke_dash_by/3","doc":"Adds a `stroke_dash` encoding for the given field.","ref":"Tucan.html#stroke_dash_by/3"},{"type":"function","title":"Options - Tucan.stroke_dash_by/3","doc":"* `:recursive` (`t:boolean/0`) - If set the grouping function will be applied recursively in all valid sub plots. This\n  includes both layers and concatenated plots. The default value is `false`.\n\n\n\n`opts` can also contain an arbitrary set of vega-lite supported options that\nwill be passed to the underlying encoding.","ref":"Tucan.html#stroke_dash_by/3-options"},{"type":"function","title":"Tucan.vconcat/2","doc":"Concatenates vertically the given plots.","ref":"Tucan.html#vconcat/2"},{"type":"function","title":"Options - Tucan.vconcat/2","doc":"* `:align` - The alignment to apply to grid rows and columns. The supported values are `:all`,\n  `:each`, and `:none`.\n\n  * For `:none`, a flow layout will be used, in which adjacent subviews are simply\n  placed one after the other.\n  * For `:each`, subviews will be aligned into a clean grid structure, but each row or\n  column may be of variable size.\n  * For `:all`, subviews will be aligned and each row or column will be sized identically\n  based on the maximum observed size. String values for this property will be applied to\n  both grid rows and columns.\n\n  Defaults to `:all` if not set.\n* `:bounds` - The bounds calculation method to use for determining the extent of a sub-plot. One\n  of `:full` (the default) or `:flush`.\n\n  * If set to `:full`, the entire calculated bounds (including axes, title, and legend)\n  will be used.\n  * If set to `:flush`, only the specified width and height values for the sub-view\n  will be used. The `:flush` setting can be useful when attempting to place sub-plots\n  without axes or legends into a uniform grid structure.\n* `:spacing` (`t:pos_integer/0`) - The spacing in pixels between sub-views of the composition operator. If not set defaults\n  to 20.\n\n#","ref":"Tucan.html#vconcat/2-options"},{"type":"function","title":"Styling Options - Tucan.vconcat/2","doc":"* `:height` (`t:integer/0`) - Height of the image\n* `:title` (`t:String.t/0`) - The title of the graph\n* `:width` (`t:integer/0`) - Width of the image","ref":"Tucan.html#vconcat/2-styling-options"},{"type":"function","title":"Tucan.vruler/3","doc":"Adds a vertical line at the given `x` position.\n\nFor supported options check `ruler/4`.","ref":"Tucan.html#vruler/3"},{"type":"type","title":"Tucan.field/0","doc":"A string corresponding to a dataset's field","ref":"Tucan.html#t:field/0"},{"type":"type","title":"Tucan.plotdata/0","doc":"The plot data.\n\nThis represents the input to all `Tucan` plots. It can be any of the following:\n\n* an existing `t:VegaLite.t/0` struct\n* a string corresponding to the url of a dataset\n* a dataset implementing the `t:Table.Reader.t/0` protocol\n* an atom corresponding to one of the supported `Tucan.Datasets`","ref":"Tucan.html#t:plotdata/0"},{"type":"module","title":"Tucan.Geometry","doc":"An API for drawing common geometrical shapes.\n\n`Tucan.Geometry` provides an API for drawing common geometrical shapes. These among other include\nlines, circles and polygons. In contrary to the `Tucan` common API, these functions instead of a\ndataset, expect the that define the underlying geometrical shapes.\n\nYou can overlay tucan plots with geometrical shapes through the `Tucan.layers/2` function.","ref":"Tucan.Geometry.html"},{"type":"module","title":"Examples - Tucan.Geometry","doc":"```tucan\nTucan.layers([\n  Tucan.Geometry.circle({3, 3}, 4, line_color: \"red\", stroke_width: 3),\n  Tucan.Geometry.rectangle({-2, 10}, {7, -3}, line_color: \"green\"),\n  Tucan.Geometry.rectangle({-3.5, 0.1}, {8.1, -4.2},\n    fill_color: \"pink\",\n    fill_opacity: 0.3\n  ),\n  Tucan.Geometry.polyline([{1, 1}, {2, 7}, {5, 3}],\n    closed: true,\n    fill_color: \"green\",\n    fill_opacity: 0.3\n  )\n])\n|> Tucan.Scale.set_xy_domain(-5, 11)\n|> Tucan.set_size(400, 400)\n|> Tucan.set_title(\"Tucan.Geometry examples\")\n```","ref":"Tucan.Geometry.html#module-examples"},{"type":"function","title":"Tucan.Geometry.circle/3","doc":"Draws a circle with the given `center` and `radius`.\n\nThe circle will be added as a new layer to the given plot `vl`.","ref":"Tucan.Geometry.html#circle/3"},{"type":"function","title":"Options - Tucan.Geometry.circle/3","doc":"#","ref":"Tucan.Geometry.html#circle/3-options"},{"type":"function","title":"Styling Options - Tucan.Geometry.circle/3","doc":"* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:opacity` (`t:number/0`) - The overall opacity of the mark\n* `:stroke_dash` (list of `t:pos_integer/0`) - An array of alternating stroke, space lengths in pixels for creating dashed\n  or dotted lines.\n* `:stroke_opacity` (`t:number/0`) - The opacity of the stroke. The default value is `1`.\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels The default value is `1`.","ref":"Tucan.Geometry.html#circle/3-styling-options"},{"type":"function","title":"Examples - Tucan.Geometry.circle/3","doc":"```tucan\nTucan.layers([\n  Tucan.Geometry.circle({3, 2}, 5),\n  Tucan.Geometry.circle({-1, 6}, 2, line_color: \"red\"),\n  Tucan.Geometry.circle({0, 1}, 4, line_color: \"green\", stroke_width: 5)\n])\n|> Tucan.Scale.set_x_domain(-5, 10)\n|> Tucan.Scale.set_y_domain(-5, 10)\n```\n\nYou can also draw filled circles by setting the `:fill_color` option. Opacity of the fill color and\nthe stroke color can be configured by `:opacity` or independently by `:fill_opacity` and\n`:stroke_opacity`.\n\n```tucan\nTucan.layers([\n  Tucan.Geometry.circle({3, 2}, 5, stroke_width: 3, stroke_opacity: 0.4),\n  Tucan.Geometry.circle({-1, 6}, 2, line_color: \"red\", fill_color: \"pink\", opacity: 0.3),\n  Tucan.Geometry.circle({0, 1}, 4, line_color: \"green\", stroke_width: 5, fill_color: \"green\", fill_opacity: 0.2)\n])\n|> Tucan.Scale.set_x_domain(-5, 10)\n|> Tucan.Scale.set_y_domain(-5, 10)\n```\n\n> ##","ref":"Tucan.Geometry.html#circle/3-examples"},{"type":"function","title":"Circles and plot dimensions {: .tip} - Tucan.Geometry.circle/3","doc":">\n> Notice that the plot must be square with identical scale domains across\n> the two axes for the circle to appear circular. In a different case it will\n> look like an ellipsis.\n>\n> ```tucan\n> circle = Tucan.Geometry.circle({0, 0}, 1)\n>\n> Tucan.hconcat([\n>   circle\n>   |> Tucan.set_size(150, 150)\n>   |> Tucan.set_title(\"Square frame\"),\n>   circle\n>   |> Tucan.Scale.set_x_domain(-2, 2)\n>   |> Tucan.Scale.set_y_domain(-1, 1)\n>   |> Tucan.set_size(150, 150)\n>   |> Tucan.set_title(\"Different domains\"),\n>   circle\n>   |> Tucan.set_size(200, 150)\n>   |> Tucan.set_title(\"Different frame dimensions\")\n> ])\n> ```","ref":"Tucan.Geometry.html#circle/3-circles-and-plot-dimensions-tip"},{"type":"function","title":"Tucan.Geometry.polyline/2","doc":"Draws a polyline defined by the given vertices.\n\nThe order of the vertices defines the order of the line segments that\nwill be generated.\n\nThe polyline or polygon will be added as a new layer to the given plot `vl`.","ref":"Tucan.Geometry.html#polyline/2"},{"type":"function","title":"Options - Tucan.Geometry.polyline/2","doc":"* `:closed` (`t:boolean/0`) - Whether a last segment will be added between the last and first points. The default value is `false`.\n\n#","ref":"Tucan.Geometry.html#polyline/2-options"},{"type":"function","title":"Styling Options - Tucan.Geometry.polyline/2","doc":"* `:fill_color` (`t:String.t/0`) - The fill color of the marks. This will override the `color` encoding if set.\n* `:fill_opacity` (`t:number/0`) - The fill opacity of the plotted elements. The default value is `1`.\n* `:line_color` (`t:String.t/0`) - The color of the line\n* `:opacity` (`t:number/0`) - The overall opacity of the mark\n* `:stroke_dash` (list of `t:pos_integer/0`) - An array of alternating stroke, space lengths in pixels for creating dashed\n  or dotted lines.\n* `:stroke_opacity` (`t:number/0`) - The opacity of the stroke. The default value is `1`.\n* `:stroke_width` (`t:pos_integer/0`) - The stroke width in pixels The default value is `1`.","ref":"Tucan.Geometry.html#polyline/2-styling-options"},{"type":"function","title":"Examples - Tucan.Geometry.polyline/2","doc":"```tucan\nTucan.Geometry.polyline([{-1, 1}, {-2, 4}, {-1, 3}, {4, 7}, {8, 2}])\n|> Tucan.Scale.set_x_domain(-3, 10)\n|> Tucan.Scale.set_y_domain(-1, 9)\n```\n\nIf `:closed` is set to `true` a line segment is added between the last and\nfirst point.\n\n```tucan\nTucan.Geometry.polyline([{-1, 1}, {-2, 4}, {-1, 3}, {4, 7}, {8, 2}], closed: true)\n|> Tucan.Scale.set_x_domain(-3, 10)\n|> Tucan.Scale.set_y_domain(-1, 9)\n```\n\nYou can change the appearance of the polyline/polygon.\n\n```tucan\npoints = [{-1, 1}, {-2, 4}, {-1, 3}, {4, 7}, {8, 2}]\n\nTucan.Geometry.polyline(points,\n  closed: true,\n  fill_color: \"red\",\n  line_color: \"green\",\n  fill_opacity: 0.3,\n  stroke_width: 3,\n  stroke_dash: [5, 3]\n)\n|> Tucan.Scale.set_x_domain(-3, 10)\n|> Tucan.Scale.set_y_domain(-1, 9)\n```","ref":"Tucan.Geometry.html#polyline/2-examples"},{"type":"function","title":"Tucan.Geometry.rectangle/3","doc":"Draws a rectangle defined by the given `upper_left` and `bottom_right` points.","ref":"Tucan.Geometry.html#rectangle/3"},{"type":"function","title":"Options - Tucan.Geometry.rectangle/3","doc":"See `polyline/2`","ref":"Tucan.Geometry.html#rectangle/3-options"},{"type":"function","title":"Examples - Tucan.Geometry.rectangle/3","doc":"```tucan\nTucan.layers([\n  Tucan.Geometry.rectangle({1, 5}, {5, 1}, line_color: \"black\", stroke_width: 2, stroke_dash: [5, 5]),\n  Tucan.Geometry.rectangle({-2, 10}, {7, -3}, line_color: \"green\"),\n  Tucan.Geometry.rectangle({-3.5, 0.1}, {8.1, -4.2}, fill_color: \"pink\", fill_opacity: 0.3)\n])\n|> Tucan.Scale.set_xy_domain(-5, 11)\n|> Tucan.set_size(400, 300)\n```","ref":"Tucan.Geometry.html#rectangle/3-examples"},{"type":"type","title":"Tucan.Geometry.point/0","doc":"A cartesian point in the form `{x, y}`","ref":"Tucan.Geometry.html#t:point/0"},{"type":"module","title":"Tucan.Layers","doc":"Utility functions for working with layered plots.","ref":"Tucan.Layers.html"},{"type":"function","title":"Tucan.Layers.append/2","doc":"Appends the given layer or layers to the input specification.\n\nIf no `layer` exists in the input spec, a new layer object will be added\nwith the `encoding` and `mark` options of the input spec.\n\nRaises if the input `vl` is not a single view or layered specification.","ref":"Tucan.Layers.html#append/2"},{"type":"function","title":"Tucan.Layers.prepend/2","doc":"Prepends the given layer or layers to the input specification.\n\nIf no `layer` exists in the input spec, a new layer object will be added\nwith the `encoding` and `mark` options of the input spec.\n\nRaises if the input `vl` is not a single view or layered specification.","ref":"Tucan.Layers.html#prepend/2"},{"type":"function","title":"Tucan.Layers.to_layered/1","doc":"Converts a single view plot to a layered plot.\n\n`encoding`, `mark` and `data` will be extracted and added to a new layer.","ref":"Tucan.Layers.html#to_layered/1"},{"type":"module","title":"Tucan.Axes","doc":"Utilities for configuring plot axes.","ref":"Tucan.Axes.html"},{"type":"function","title":"Tucan.Axes.put_options/3","doc":"Sets an arbitrary set of options to the given `encoding` axis object.\n\nNotice that no validation is performed, any option set will be merged with\nthe existing `axis` options of the given `encoding`.\n\nAn `ArgumentError` is raised if the given encoding channel is not defined.","ref":"Tucan.Axes.html#put_options/3"},{"type":"function","title":"Tucan.Axes.set_enabled/2","doc":"Enables or disables both axes (`x`, `y`) at once.\n\nSee also `set_enabled/3`","ref":"Tucan.Axes.html#set_enabled/2"},{"type":"function","title":"Tucan.Axes.set_enabled/3","doc":"Enables or disables the given axis.\n\nNotice that axes are enabled by default.","ref":"Tucan.Axes.html#set_enabled/3"},{"type":"function","title":"Examples - Tucan.Axes.set_enabled/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Axes.set_enabled(:x, false)\n|> Tucan.Axes.set_enabled(:y, false)\n```","ref":"Tucan.Axes.html#set_enabled/3-examples"},{"type":"function","title":"Tucan.Axes.set_offset/3","doc":"Sets the axis offset (in pixels).\n\nThe offset indicates the amount in pixels by which the axis will be  displaces from the\nedge of the enclosing group or data rectangle.","ref":"Tucan.Axes.html#set_offset/3"},{"type":"function","title":"Examples - Tucan.Axes.set_offset/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Axes.set_offset(:y, 10)\n|> Tucan.Grid.set_enabled(false)\n```","ref":"Tucan.Axes.html#set_offset/3-examples"},{"type":"function","title":"Tucan.Axes.set_orientation/3","doc":"Sets the orientation for the given axis.\n\nValid values for `orient` are:\n\n* `:top`, `:bottom` for the x axis\n* `:left`, `:right` for the y axis","ref":"Tucan.Axes.html#set_orientation/3"},{"type":"function","title":"Examples - Tucan.Axes.set_orientation/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Axes.set_orientation(:x, :top)\n|> Tucan.Axes.set_orientation(:y, :right)\n```","ref":"Tucan.Axes.html#set_orientation/3-examples"},{"type":"function","title":"Tucan.Axes.set_title/3","doc":"Set the title of the given `axis`.","ref":"Tucan.Axes.html#set_title/3"},{"type":"function","title":"Tucan.Axes.set_x_title/2","doc":"Sets the x axis title.","ref":"Tucan.Axes.html#set_x_title/2"},{"type":"function","title":"Tucan.Axes.set_xy_titles/3","doc":"Sets the _x-axis_ and _y-axis_ titles at once.","ref":"Tucan.Axes.html#set_xy_titles/3"},{"type":"function","title":"Tucan.Axes.set_y_title/2","doc":"Sets the y axis title.","ref":"Tucan.Axes.html#set_y_title/2"},{"type":"type","title":"Tucan.Axes.axis/0","doc":"","ref":"Tucan.Axes.html#t:axis/0"},{"type":"type","title":"Tucan.Axes.orient/0","doc":"","ref":"Tucan.Axes.html#t:orient/0"},{"type":"module","title":"Tucan.Grid","doc":"Helper utilities for customizing a plot's grid.","ref":"Tucan.Grid.html"},{"type":"function","title":"Tucan.Grid.set_color/3","doc":"Set a specific color to the grid for the given channel.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_color/3"},{"type":"function","title":"Examples - Tucan.Grid.set_color/3","doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:y, \"red\")\n|> Tucan.Grid.set_color(:x, \"#2A32F4\")\n```","ref":"Tucan.Grid.html#set_color/3-examples"},{"type":"function","title":"Tucan.Grid.set_dash_style/4","doc":"Sets the dash style of the grid.\n\n`stroke` and `space` are alternative lengths for the dashed grid lines in pixels.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_dash_style/4"},{"type":"function","title":"Examples - Tucan.Grid.set_dash_style/4","doc":"A scatter plot with the different dashed styles across the two axes:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_dash_style(:x, 10, 2)\n|> Tucan.Grid.set_dash_style(:y, 2, 10)\n```","ref":"Tucan.Grid.html#set_dash_style/4-examples"},{"type":"function","title":"Tucan.Grid.set_enabled/2","doc":"Enables or disables the grid for the plot.\n\nNotice that the grid is enabled by default.\n\nSee also `set_enabled/3` for enabling/disabling specific axis' grid.","ref":"Tucan.Grid.html#set_enabled/2"},{"type":"function","title":"Examples - Tucan.Grid.set_enabled/2","doc":"A scatter plot with the grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(false)\n```","ref":"Tucan.Grid.html#set_enabled/2-examples"},{"type":"function","title":"Tucan.Grid.set_enabled/3","doc":"Enable or disable the grid of a specific `channel`\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_enabled/3"},{"type":"function","title":"Examples - Tucan.Grid.set_enabled/3","doc":"A scatter plot with the `y-axis` grid disabled:\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_enabled(:y, false)\n```","ref":"Tucan.Grid.html#set_enabled/3-examples"},{"type":"function","title":"Tucan.Grid.set_opacity/3","doc":"Sets the opacity of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_opacity/3"},{"type":"function","title":"Examples - Tucan.Grid.set_opacity/3","doc":"A scatter plot with the `y-axis` grid colored red and `x-axis` grid with a custom RGB color and\nopacity values set. Also the width is increased to make the opacity changes more clear.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Grid.set_color(:x, \"red\")\n|> Tucan.Grid.set_color(:y, \"cyan\")\n|> Tucan.Grid.set_opacity(:x, 0.1)\n|> Tucan.Grid.set_opacity(:y, 0.8)\n|> Tucan.Grid.set_width(:x, 3)\n|> Tucan.Grid.set_width(:y, 3)\n```","ref":"Tucan.Grid.html#set_opacity/3-examples"},{"type":"function","title":"Tucan.Grid.set_width/3","doc":"Sets the width of the grid lines.\n\nIf not set it defaults to 1.\n\nThis will raise if the `channel` is not encoded.","ref":"Tucan.Grid.html#set_width/3"},{"type":"module","title":"Tucan.Legend","doc":"Helper utilities for configuring the plot legend.","ref":"Tucan.Legend.html"},{"type":"function","title":"Tucan.Legend.put_options/3","doc":"Set arbitrary options to the legend of the given channel.\n\nThe options are deep merged with existing options.","ref":"Tucan.Legend.html#put_options/3"},{"type":"function","title":"Examples - Tucan.Legend.put_options/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.Legend.put_options(:color, fill_color: \"yellow\", offset: 5, padding: 2, label_font_size: 14)\n```","ref":"Tucan.Legend.html#put_options/3-examples"},{"type":"function","title":"Tucan.Legend.set_enabled/3","doc":"Enables or disables the legend of the given encoding channel.","ref":"Tucan.Legend.html#set_enabled/3"},{"type":"function","title":"Tucan.Legend.set_offset/3","doc":"Sets the offset in pixels by which to displace the legend from the data rectangle\nand axes.\n\nIf not set defaults to 18 pixels.","ref":"Tucan.Legend.html#set_offset/3"},{"type":"function","title":"Examples - Tucan.Legend.set_offset/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.Legend.set_offset(:color, 5)\n```","ref":"Tucan.Legend.html#set_offset/3-examples"},{"type":"function","title":"Tucan.Legend.set_orientation/3","doc":"Sets the legend orientation with respect to the scene.\n\nYou need to define the `channel` for which the legend will be configured. Orientation\ncan be one of the following: `[\"left\", \"right\", \"top\", \"bottom\", \"top-left\", \"top-right\", \"bottom-left\", \"bottom-right\", \"none\"]`.\n\nApplicable only on plots with a legend.","ref":"Tucan.Legend.html#set_orientation/3"},{"type":"function","title":"Examples - Tucan.Legend.set_orientation/3","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:shape, \"top\")\n```","ref":"Tucan.Legend.html#set_orientation/3-examples"},{"type":"function","title":"Tucan.Legend.set_title/4","doc":"Sets the title of the given legend.\n\nYou can optionally pass any title option supported by vega-lite to customize the\nstyle of it.\n\nApplicable only on plots with a legend.","ref":"Tucan.Legend.html#set_title/4"},{"type":"function","title":"Examples - Tucan.Legend.set_title/4","doc":"```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.Legend.set_title(:color, \"Iris Species\", title_color: \"red\", title_font_weight: 300)\n```","ref":"Tucan.Legend.html#set_title/4-examples"},{"type":"module","title":"Tucan.Scale","doc":"Utilities for working with Vega-Lite scales.\n\nScales are functions that transform a domain of data values (numbers, dates, strings, etc.)\nto a range of visual values (pixels, colors, sizes).\n\nThis module exposes various helper functions for setting various scale options like\nthe color scheme, the domain or the scale type.","ref":"Tucan.Scale.html"},{"type":"function","title":"Tucan.Scale.put_options/3","doc":"Sets an arbitrary set of options to the given `encoding`'s scale object.\n\nNotice that no validation is performed, any option set will be merged with\nthe existing `scale` options of the given `encoding`.\n\nAn `ArgumentError` is raised if the given encoding channel is not defined.","ref":"Tucan.Scale.html#put_options/3"},{"type":"function","title":"Tucan.Scale.set_color_scheme/3","doc":"Sets the color scheme.\n\nYou can either set one of the predefined schemes, or an array of colors which will\nbe used as the color range.\n\nThe input plot must be a single view with a color encoding defined.","ref":"Tucan.Scale.html#set_color_scheme/3"},{"type":"function","title":"Options - Tucan.Scale.set_color_scheme/3","doc":"* `:reverse` (`t:boolean/0`) - If set to `true` the selected scheme is reversed. Ignored if a range is set. The default value is `false`.","ref":"Tucan.Scale.html#set_color_scheme/3-options"},{"type":"function","title":"Supported color schemes - Tucan.Scale.set_color_scheme/3","doc":"All [vega supported schemes](https://vega.github.io/vega/docs/schemes/) are supported\nby `Tucan`.\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-supported-color-schemes"},{"type":"function","title":"Categorical Schemes - Tucan.Scale.set_color_scheme/3","doc":"Categorical color schemes can be used to encode discrete data values, each representing\na distinct category.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-categorical-schemes"},{"type":"function","title":"Sequential Single-Hue Schemes - Tucan.Scale.set_color_scheme/3","doc":"Sequential color schemes can be used to encode quantitative values. These\ncolor ramps are designed to encode increasing numeric values.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-sequential-single-hue-schemes"},{"type":"function","title":"Sequential Multi-Hue Schemes - Tucan.Scale.set_color_scheme/3","doc":"Sequential color schemes can be used to encode quantitative values. These color\nramps are designed to encode increasing numeric values, but use additional\nhues for more color discrimination, which may be useful for visualizations\nsuch as heatmaps.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-sequential-multi-hue-schemes"},{"type":"function","title":"Schemes for Dark Backgrounds - Tucan.Scale.set_color_scheme/3","doc":"#","ref":"Tucan.Scale.html#set_color_scheme/3-schemes-for-dark-backgrounds"},{"type":"function","title":"Schemes for Light Backgrounds - Tucan.Scale.set_color_scheme/3","doc":"#","ref":"Tucan.Scale.html#set_color_scheme/3-schemes-for-light-backgrounds"},{"type":"function","title":"Diverging Schemes - Tucan.Scale.set_color_scheme/3","doc":"Diverging color schemes can be used to encode quantitative values with a meaningful\nmid-point, such as zero or the average value. Color ramps with different hues\ndiverge with increasing saturation to highlight the values below and above the\nmid-point.\n\n\n\n\n#","ref":"Tucan.Scale.html#set_color_scheme/3-diverging-schemes"},{"type":"function","title":"Cyclical Schemes - Tucan.Scale.set_color_scheme/3","doc":"Cyclical color schemes may be used to highlight periodic patterns in continuous\ndata. However, these schemes are not well suited to accurately convey value\ndifferences.","ref":"Tucan.Scale.html#set_color_scheme/3-cyclical-schemes"},{"type":"function","title":"Examples - Tucan.Scale.set_color_scheme/3","doc":"Setting a specific color range\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", color_by: \"species\")\n|> Tucan.Scale.set_color_scheme([\"yellow\", \"black\", \"#f234c1\"])\n```\n\nYou can set any of the predefined color schemes to any plot with a color\nencoding.\n\n```tucan\nTucan.scatter(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :monthdate],\n  y: [aggregate: :mean],\n  color_by: \"temp_max\",\n  color: [aggregate: :mean, type: :quantitative],\n  width: 400\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue)\n\n```\n\nYou can reverse it by setting the `:reverse` option:\n\n```tucan\nTucan.scatter(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :monthdate],\n  y: [aggregate: :mean],\n  color_by: \"temp_max\",\n  color: [aggregate: :mean, type: :quantitative],\n  width: 400\n)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n\n```","ref":"Tucan.Scale.html#set_color_scheme/3-examples"},{"type":"function","title":"Tucan.Scale.set_domain/3","doc":"Sets the domain for the given encoding channel.\n\n`domain` can be anything Vega-Lite supports and the validity of it depends on the type\nof the encoding's data.\n\nNotice that no validation is performed.","ref":"Tucan.Scale.html#set_domain/3"},{"type":"function","title":"Tucan.Scale.set_scale/4","doc":"Sets the scale for the given encoding channel.\n\nNotice that only continuous scales are supported.\n\nSee also `set_x_scale/3` and `set_y_scale/3` wrappers for setting the scale\ndirectly on *x* and *y* axes.\n\n> ##","ref":"Tucan.Scale.html#set_scale/4"},{"type":"function","title":"Continuous Scales {: .neutral} - Tucan.Scale.set_scale/4","doc":">\n> Continuous scales map a continuous domain (numbers or dates) to a continuous\n> output range (pixel locations, sizes, colors). Supported continuous scale\n> types for quantitative fields are `:linear`, `:log`, `:pow`, `:sqrt`, and\n> `:symlog`.\n>\n> Meanwhile, supported continuous scale types for temporal fields are `:time`,\n> `:utc`, and `:symlog`.\n>\n> By default, `:linear` scales are used for quantitative fields and `:time`\n> scales are used for temporal fields for all encoding channels.","ref":"Tucan.Scale.html#set_scale/4-continuous-scales-neutral"},{"type":"function","title":"Options - Tucan.Scale.set_scale/4","doc":"The supported options depend on the selected scale.\n\n### `:pow` scale\n\n* `:exponent` (`t:number/0`) - The exponent to be used, applicable only for `:pow`\nscale.\n\n### `:log` scale\n\n* `:base` (`t:number/0`) - The logarithm base of the `:log` scale. If not set defaults\nto 10.\n\n### `:symlog` scale\n\n* `:constant` (`t:number/0`) - A constant determining the slope of the symlog\nfunction around zero. If not set defaults to 1.","ref":"Tucan.Scale.html#set_scale/4-options"},{"type":"function","title":"Examples - Tucan.Scale.set_scale/4","doc":"Applying log scale on *x-axis*.\n\n```tucan\nTucan.scatter(:gapminder, \"income\", \"health\", width: 400)\n|> Tucan.Scale.set_scale(:x, :log)\n```\n\nApplying pow scale on *x-axis* with arbitrary exponent.\n\n```tucan\nTucan.scatter(:gapminder, \"income\", \"health\", width: 400)\n|> Tucan.Scale.set_scale(:x, :pow, exponent: 0.2)\n```","ref":"Tucan.Scale.html#set_scale/4-examples"},{"type":"function","title":"Tucan.Scale.set_x_domain/3","doc":"Sets the _x-axis_ domain.\n\nThis is a helper wrapper around `set_domain/3` for setting the domain of continuous\nscales.","ref":"Tucan.Scale.html#set_x_domain/3"},{"type":"function","title":"Tucan.Scale.set_x_scale/3","doc":"Sets the x axis scale.","ref":"Tucan.Scale.html#set_x_scale/3"},{"type":"function","title":"Options - Tucan.Scale.set_x_scale/3","doc":"See `set_scale/4`.","ref":"Tucan.Scale.html#set_x_scale/3-options"},{"type":"function","title":"Tucan.Scale.set_xy_domain/3","doc":"Sets the same `[x, y]` domain for _x-axis_ and _y-axis_ at once.","ref":"Tucan.Scale.html#set_xy_domain/3"},{"type":"function","title":"Tucan.Scale.set_y_domain/3","doc":"Sets the _y-axis_ domain.\n\nThis is a helper wrapper around `set_domain/3` for setting the domain of continuous\nscales.","ref":"Tucan.Scale.html#set_y_domain/3"},{"type":"function","title":"Tucan.Scale.set_y_scale/3","doc":"Sets the y axis scale.","ref":"Tucan.Scale.html#set_y_scale/3"},{"type":"function","title":"Options - Tucan.Scale.set_y_scale/3","doc":"See `set_scale/4`.","ref":"Tucan.Scale.html#set_y_scale/3-options"},{"type":"type","title":"Tucan.Scale.color_scheme/0","doc":"","ref":"Tucan.Scale.html#t:color_scheme/0"},{"type":"module","title":"Tucan.Themes","doc":"Helper functions for `Tucan` theme.\n\nA `Tucan` theme is nothing more than a keyword list with a `VegaLite` configuration\nobject with some styles applied and some metadata. Every theme must have the\nfollowing format:\n\n    [\n       theme: [],          # the actual theme configuration\n       name: :name,        # an atom with a unique name\n       doc: \"description\", # a description of the theme,\n       source: \"url\"       # a url to the source of the theme if any for attribution \n    ]","ref":"Tucan.Themes.html"},{"type":"module","title":"Default themes - Tucan.Themes","doc":"`Tucan` comes pre-packed with a set of themes, borrowed by the [Vega Themes](https://github.com/vega/vega-themes)\nproject. You can set a theme to a plot by calling the `Tucan.set_theme/2` function. If no\ntheme set the default vega-lite theme is used. In all examples below the following example\nplot is used:\n\n```tucan\nscatter =\n  Tucan.scatter(:iris, \"petal_width\", \"petal_length\", tooltip: true)\n  |> Tucan.color_by(\"species\")\n  |> Tucan.shape_by(\"species\")\n\nlines = Tucan.lineplot(:stocks, \"date\", \"price\", color_by: \"symbol\", x: [type: :temporal])\n\narea =\n  Tucan.area(:stocks, \"date\", \"price\", color_by: \"symbol\", mode: :normalize, x: [type: :temporal])\n\ndensity = Tucan.density(:penguins, \"Body Mass (g)\", color_by: \"Species\", fill_opacity: 0.2)\n\nstrip =\n  Tucan.stripplot(:tips, \"total_bill\", group_by: \"day\", style: :jitter)\n  |> Tucan.color_by(\"sex\")\n\nboxplot = Tucan.boxplot(:penguins, \"Body Mass (g)\", color_by: \"Species\")\nhistogram = Tucan.histogram(:cars, \"Horsepower\", color_by: \"Origin\", fill_opacity: 0.5)\n\npie = Tucan.pie(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\ndonut = Tucan.donut(:barley, \"yield\", \"site\", aggregate: :sum, tooltip: true)\n\nheatmap =\n  Tucan.density_heatmap(:penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\")\n\nTucan.vconcat(\n  [\n    Tucan.hconcat([scatter, lines, area]),\n    Tucan.hconcat([density, Tucan.vconcat([strip, boxplot]), histogram]),\n    Tucan.hconcat([pie, donut, heatmap])\n  ]\n)\n|> VegaLite.config(legend: [disable: true])\n|> VegaLite.resolve(:scale, color: :independent)\n\n```\n\nThe following themes are currently supported:\n\n### `:dark`\n\nA dark theme [[source](https://github.com/vega/vega-themes/blob/main/src/theme-dark.ts)]\n\n**Example:**\n\n\n\n\n### `:excel`\n\nChart theme modeled after `excel` [[source](https://github.com/vega/vega-themes/blob/main/src/theme-excel.ts)]\n\n**Example:**\n\n\n\n\n### `:five_thirty_eight`\n\nChart theme modeled after FiveThirtyEight [[source](https://github.com/vega/vega-themes/blob/main/src/theme-fivethirtyeight.ts)]\n\n**Example:**\n\n\n\n\n### `:ggplot2`\n\nChart theme modeled after `ggplot2` [[source](https://github.com/vega/vega-themes/blob/main/src/theme-ggplot2.ts)]\n\n**Example:**\n\n\n\n\n### `:google_charts`\n\nChart theme modeled after Google Charts [[source](https://github.com/vega/vega-themes/blob/main/src/theme-googlecharts.ts)]\n\n**Example:**\n\n\n\n\n### `:latimes`\n\nChart theme modeled after the Los Angeles Times [[source](https://github.com/vega/vega-themes/blob/main/src/theme-latimes.ts)]\n\n**Example:**\n\n\n\n\n### `:power_bi`\n\nChart theme modeled after Power BI [[source](https://github.com/vega/vega-themes/blob/main/src/theme-powerbi.ts)]\n\n**Example:**\n\n\n\n\n### `:quartz`\n\nChart theme modeled after Quartz [[source](https://github.com/vega/vega-themes/blob/main/src/theme-quartz.ts)]\n\n**Example:**\n\n\n\n\n### `:urban_institute`\n\nChart theme modeled after Urban Institute [[source](https://github.com/vega/vega-themes/blob/main/src/theme-urbaninstitute.ts)]\n\n**Example:**\n\n\n\n\n### `:vox`\n\nChart theme modeled after Vox [[source](https://github.com/vega/vega-themes/blob/main/src/theme-vox.ts)]\n\n**Example:**","ref":"Tucan.Themes.html#module-default-themes"},{"type":"function","title":"Tucan.Themes.theme/1","doc":"Returns the configuration object for the given theme.\n\nAn exception will be raised if the theme name is invalid.","ref":"Tucan.Themes.html#theme/1"},{"type":"module","title":"Tucan.View","doc":"Helper utilities for customizing the plot view.","ref":"Tucan.View.html"},{"type":"function","title":"Tucan.View.set_background/2","doc":"Sets the background color of the visualization canvas.","ref":"Tucan.View.html#set_background/2"},{"type":"function","title":"Examples - Tucan.View.set_background/2","doc":"```tucan\nTucan.scatter(:iris, \"sepal_width\", \"sepal_length\")\n|> Tucan.View.set_background(\"#fcffde\")\n```","ref":"Tucan.View.html#set_background/2-examples"},{"type":"function","title":"Tucan.View.set_view_background/2","doc":"Sets the background color of the view.\n\n`set_background/2` defines the background of the whole visualization canvas. Meanwhile,\nthe view property of a single-view or layer specification can define the background of\nthe view.","ref":"Tucan.View.html#set_view_background/2"},{"type":"function","title":"Examples - Tucan.View.set_view_background/2","doc":"Two concatenated plots with different view backgrounds and an overall canvas\nbackground.\n\n```tucan\nTucan.hconcat(\n  [\n    Tucan.scatter(:iris, \"sepal_width\", \"sepal_length\")\n    |> Tucan.View.set_view_background(\"#e6fae1\"),\n    Tucan.scatter(:iris, \"petal_width\", \"petal_length\")\n    |> Tucan.View.set_view_background(\"#facbc5\"),\n  ]\n)\n|> Tucan.View.set_background(\"#fcffde\")\n```","ref":"Tucan.View.html#set_view_background/2-examples"},{"type":"module","title":"Tucan.Datasets","doc":"Common datasets for `Tucan` demos and docs.","ref":"Tucan.Datasets.html"},{"type":"module","title":"Supported datasets - Tucan.Datasets","doc":"Currently the following datasets are supported:\n\n##","ref":"Tucan.Datasets.html#module-supported-datasets"},{"type":"module","title":"barley - Tucan.Datasets","doc":"[Yield data](https://stat.ethz.ch/R-manual/R-devel/library/lattice/html/barley.html) from a\nMinnesota barley trial. Includes total yield in bushels per acre for 10 varieties at 6 sites\nin each of two years.\n [[Data]](https://vega.github.io/editor/data/barley.json).\n\n**Columns: ** `yield`, `variety`, `year`, `site`\n\n##","ref":"Tucan.Datasets.html#module-barley"},{"type":"module","title":"cars - Tucan.Datasets","doc":"This was the 1983 ASA Data Exposition dataset. The dataset was collected by Ernesto Ramos and\nDavid Donoho and dealt with automobiles. I don't remember the instructions for analysis. Data\non mpg, cylinders, displacement, etc. (8 variables) for 406 different cars. [[Source]](http://lib.stat.cmu.edu/datasets/)\n [[Data]](https://vega.github.io/editor/data/cars.json).\n\n**Columns: ** `Name`, `Miles_per_Gallon`, `Cylinders`, `Displacement`, `Horsepower`, `Weight_in_lbs`, `Acceleration`, `Year`, `Origin`\n\n##","ref":"Tucan.Datasets.html#module-cars"},{"type":"module","title":"corruption - Tucan.Datasets","doc":"Corruption Perceptions Index (CPI) and Human Development Index (HDI) for 176 countries,\nfrom 2012 to 2015.\n [[Data]](https://raw.githubusercontent.com/holtzy/The-Python-Graph-Gallery/master/static/data/corruption.csv).\n\n**Columns: ** `country`, `region`, `year`, `cpi`, `iso3c`, `hdi`\n\n##","ref":"Tucan.Datasets.html#module-corruption"},{"type":"module","title":"flights - Tucan.Datasets","doc":"Monthly airline passengers from 1949 to 1960. \n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/flights.csv).\n\n**Columns: ** `year`, `month`, `passengers`\n\n##","ref":"Tucan.Datasets.html#module-flights"},{"type":"module","title":"gapminder - Tucan.Datasets","doc":"[Gapminder](https://www.gapminder.org/) health & income by country data.\n [[Data]](https://vega.github.io/vega-datasets/data/gapminder-health-income.csv).\n\n**Columns: ** `country`, `income`, `health`, `population`, `region`\n\n##","ref":"Tucan.Datasets.html#module-gapminder"},{"type":"module","title":"glue - Tucan.Datasets","doc":"Data from the [GLUE (The General Language Understanding Evaluation) benchmark\nleaderboard](https://gluebenchmark.com/leaderboard).\n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/glue.csv).\n\n**Columns: ** `Model`, `Year`, `Encoder`, `Task`, `Score`\n\n##","ref":"Tucan.Datasets.html#module-glue"},{"type":"module","title":"iris - Tucan.Datasets","doc":"This is one of the earliest datasets used in the literature on classification methods and widely\nused in statistics and machine learning.  The data set contains 3 classes of 50 instances each,\nwhere each class refers to a type of iris plant.\n [[Data]](https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv).\n\n**Columns: ** `sepal_length`, `sepal_width`, `petal_length`, `petal_width`, `species`\n\n##","ref":"Tucan.Datasets.html#module-iris"},{"type":"module","title":"movies - Tucan.Datasets","doc":"Movies dataset including IMDB scores. The dataset has well known and intentionally included\nerrors. This dataset is used for instructional purposes, including the need to reckon with\ndirty data.\n [[Data]](https://vega.github.io/editor/data/movies.json).\n\n**Columns: ** `Creative Type`, `Director`, `Distributor`, `IMDB Rating`, `IMDB Votes`, `MPAA Rating`, `Major Genre`, `Production Budget`, `Release Date`, `Rotten Tomatoes Rating`, `Running Time min`, `Source`, `Title`, `US DVD Sales`, `US Gross`, `Worldwide Gross`\n\n##","ref":"Tucan.Datasets.html#module-movies"},{"type":"module","title":"penguins - Tucan.Datasets","doc":"The [dataset](https://github.com/allisonhorst/palmerpenguins) contains data for 344 penguins.\nThere are 3 different species of penguins in this dataset, collected from 3 islands in the\nPalmer Archipelago, Antarctica. This is an excellent dataset for data exploration\n& visualization, as an alternative to `:iris`.\n\nData were collected and made available by [Dr. Kristen Gorman](https://www.uaf.edu/cfos/people/faculty/detail/kristen-gorman.php)\nand the [Palmer Station, Antarctica LTER](https://pallter.marine.rutgers.edu/), a member of\nthe [Long Term Ecological Research Network](https://lternet.edu/).\n [[Data]](https://raw.githubusercontent.com/vega/vega-datasets/next/data/penguins.json).\n\n**Columns: ** `Beak Depth (mm)`, `Beak Length (mm)`, `Body Mass (g)`, `Flipper Length (mm)`, `Island`, `Sex`, `Species`\n\n##","ref":"Tucan.Datasets.html#module-penguins"},{"type":"module","title":"stocks - Tucan.Datasets","doc":"Daily closing prices of various stocks. [[Data]](https://vega.github.io/editor/data/stocks.csv).\n\n**Columns: ** `symbol`, `date`, `price`\n\n##","ref":"Tucan.Datasets.html#module-stocks"},{"type":"module","title":"tips - Tucan.Datasets","doc":"[Tipping data](https://rdrr.io/cran/reshape2/man/tips.html) as collected by one waiter.\nInformation about each tip he received over a period of a few months working in one restaurant\nis included.\n [[Data]](https://raw.githubusercontent.com/mwaskom/seaborn-data/master/tips.csv).\n\n**Columns: ** `total_bill`, `tip`, `sex`, `smoker`, `day`, `time`, `size`\n\n##","ref":"Tucan.Datasets.html#module-tips"},{"type":"module","title":"titanic - Tucan.Datasets","doc":"Titanic survival data from the [legendary Kaggle competition](https://www.kaggle.com/competitions/titanic/data).\n [[Data]](https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv).\n\n**Columns: ** `PassengerId`, `Survived`, `Pclass`, `Name`, `Sex`, `Age`, `SibSp`, `Parch`, `Ticket`, `Fare`, `Cabin`, `Embarked`\n\n##","ref":"Tucan.Datasets.html#module-titanic"},{"type":"module","title":"unemployment - Tucan.Datasets","doc":"US unemployment data across various industries from 2000 to 2009.\n [[Data]](https://vega.github.io/editor/data/unemployment-across-industries.json).\n\n**Columns: ** `count`, `date`, `month`, `rate`, `series`, `year`\n\n##","ref":"Tucan.Datasets.html#module-unemployment"},{"type":"module","title":"weather - Tucan.Datasets","doc":"Daily weather records from Seattle with metric units. [Data from NOAA](https://www.ncdc.noaa.gov/cdo-web/datatools/records).\n [[Data]](https://vega.github.io/editor/data/weather.csv).\n\n**Columns: ** `date`, `precipitation`, `temp_max`, `temp_min`, `wind`, `weather`","ref":"Tucan.Datasets.html#module-weather"},{"type":"function","title":"Tucan.Datasets.dataset/1","doc":"Reruns the url of the given dataset.\n\nRaises an error if the dataset is invalid.","ref":"Tucan.Datasets.html#dataset/1"},{"type":"type","title":"Tucan.Datasets.t/0","doc":"","ref":"Tucan.Datasets.html#t:t/0"},{"type":"extras","title":"Tucan","doc":"# Tucan\n\n[![Actions Status](https://github.com/pnezis/tucan/actions/workflows/elixir.yml/badge.svg)](https://github.com/pnezis/tucan/actions)\n[![Package](https://img.shields.io/badge/-Package-important)](https://hex.pm/packages/tucan)\n[![Documentation](https://img.shields.io/badge/-Documentation-blueviolet)](https://hexdocs.pm/tucan/Tucan.html)\n\n`Tucan` is an Elixir plotting library built on top of `VegaLite`, designed to simplify\nthe creation of interactive and visually stunning plots. With `Tucan`, you can effortlessly\ngenerate a wide range of plots, from simple bar charts to complex composite plots, all\nwhile enjoying the power and flexibility of a clean composable functional API.\n\n`Tucan` offers a simple API for creating most common plot types similarly to `matplotlib`\nand `seaborn` without requiring the end user to be familiar with the Vega Lite grammar.\n\n![Tucan](https://github.com/pnezis/tucan/raw/main/assets/tucan.png)","ref":"readme.html"},{"type":"extras","title":"Features - Tucan","doc":"- **Versatile Plot Types** - `Tucan` provides an array of plot types, including bar charts,\nline plots, scatter plots, histograms, and more, allowing you to effectively represent\ndiverse data sets.\n- **Clean and consistent API** - A clean and consistent plotting API similar to `matplotlib`\nor `seaborn` is provided. You should be able to create most common plots with a single\nfunction call and minimal configuration.\n- **Grouping and Faceting** - Enhance your visualizations with grouping and faceting\nfeatures, enabling you to examine patterns and trends within subgroups of your data.\n- **Customization** - Customize your plots with ease using Tucan's utilities for adjusting\nplot dimensions, titles, and **themes**.\n- **Thin wrapper on top of VegaLite** - All `VegaLite` functions can be used seamlessly with\n`Tucan` in order to enhance/customize your plots.\n- **`Nx` support** - You can pass directly `Nx` tensors in all plot functions.\n- **Low level API** - A low level API with helper functions is provided for modifying\n`VegaLite` specifications.","ref":"readme.html#features"},{"type":"extras","title":"Basic usage - Tucan","doc":"```elixir\n# A simple scatter plot\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n\n# You can combine it with one or more semantic grouping functions\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.color_by(\"species\")\n|> Tucan.shape_by(\"species\")\n\n# You can pipe it through other Tucan functions to modify the look & feel\nTucan.bubble(:gapminder, \"income\", \"health\", \"population\",\n  color_by: \"region\",\n  tooltip: true\n)\n|> Tucan.set_width(400)\n|> Tucan.Axes.set_x_title(\"Gdp per Capita\")\n|> Tucan.Axes.set_y_title(\"Life expectancy\")\n|> Tucan.Scale.set_x_scale(:log)\n\n# Some composite plots are also supported\nfields = [\"petal_width\", \"petal_length\", \"sepal_width\", \"sepal_length\"]\n\nTucan.pairplot(:iris, , width: 130, height: 130)\n|> Tucan.color_by(\"species\", recursive: true)\n\n# creating facet plots is very easy with the facet_by/4 function\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.facet_by(:column, \"species\")\n|> Tucan.color_by(\"species\")\n```\n\nRead the [docs](https://hexdocs.pm/tucan/Tucan.html) for more examples.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Installation - Tucan","doc":"#","ref":"readme.html#installation"},{"type":"extras","title":"Inside Livebook - Tucan","doc":"You most likely want to use Tucan in [Livebook](https://github.com/livebook-dev/livebook),\nin which case you can call `Mix.install/2`:\n\n```elixir\nMix.install([\n  {:tucan, \"~> 0.3.0\"},\n  {:kino_vega_lite, \"~> 0.1.8\"}\n])\n```\n\nYou will also want [kino_vega_lite](https://github.com/livebook-dev/kino_vega_lite) to ensure\nLivebook renders the graphics nicely.\n\n#","ref":"readme.html#inside-livebook"},{"type":"extras","title":"In Mix projects - Tucan","doc":"You can add the `:tucan` dependency to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tucan, \"~> 0.3.0\"}\n  ]\nend\n```\n\n**NOTE:** While I will try to maintain backwards compatibility as much as possible, since this\nis still a 0.x.x project the API is not considered stable and thus subject to possible breaking\nchanges up until v1.0.0.","ref":"readme.html#in-mix-projects"},{"type":"extras","title":"Acknowledgements - Tucan","doc":"- [vega-lite](https://vega.github.io/vega-lite/) and the awesome docs of it, many examples\nand most of the datasets used are based on it.\n- The elixir [VegaLite](https://github.com/livebook-dev/vega_lite) bindings\n- [seaborn](https://seaborn.pydata.org/), [matplotlib](https://matplotlib.org/) and\n[ggplot2](https://ggplot2.tidyverse.org/) upon which the high level API is partially based.\n- [vega-themes](https://github.com/vega/vega-themes) from which the existing themes are\nported.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"License - Tucan","doc":"Copyright (c) 2023 Panagiotis Nezis\n\nTucan is released under the MIT License. See the [LICENSE](LICENSE) file for more details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v0.3.1](https://github.com/pnezis/tucan/tree/v0.3.1) (2024-01-20)\n\n#","ref":"changelog.html"},{"type":"extras","title":"Added plot options - Changelog","doc":"- Support `:fill_color` and `:corner_radius` in `Tucan.bar/4`\n- Support `:fill_color` and `:corner_radius` in `Tucan.histogram/3`\n- Support `:fill_color`, `:point_color` and `:line_color` in `Tucan.area/4`\n\n## [v0.3.0](https://github.com/pnezis/tucan/tree/v0.3.0) (2024-01-03)\n\n#","ref":"changelog.html#added-plot-options"},{"type":"extras","title":"Added - Changelog","doc":"- `Nx` support, you can pass directly tensors as data series.\n\n```tucan\nx = Nx.linspace(-20, 20, n: 200)\ny = Nx.pow(x, 2)\n\nTucan.lineplot([x: x, y: y], \"x\", \"y\", width: 400)\n```\n\n- Add `Tucan.imshow/2` for rendering pseudo-color images\n\n```tucan\nimage = Nx.tensor([[1, 2, 3, 4], [5, 6, 7, 8], [9, 10, 11, 12]], type: {:f, 32})\n\nTucan.imshow(image, show_scale: true, width: 200, height: 150)\n```\n\n- Add `Tucan.errorbar/3` plot\n\n```tucan\nTucan.errorbar(:barley, \"yield\", group_by: \"variety\", points: true, ticks: true)\n|> Tucan.color_by(\"variety\")\n```\n\n- Add `Tucan.errorband/4` plot\n\n```tucan\nTucan.errorband(:cars, \"Year\", \"Miles_per_Gallon\",\n  extent: :ci,\n  fill_color: \"black\",\n  borders: true,\n  x: [time_unit: \"year\", type: :temporal]\n)\n```\n\n- Add `Tucan.lollipop/4` plot\n\n```tucan\ndata = [\n  category: [\"A\", \"B\", \"C\", \"D\"],\n  value: [90, 72, 81, 50, 64]\n]\n\nTucan.lollipop(data, \"category\", \"value\",\n  orient: :horizontal,\n  point_color: \"red\",\n  width: 300\n)\n|> Tucan.Scale.set_x_domain(30, 100)\n```\n\n- Add `Tucan.Geometry.polyline/2` and `Tucan.Geometry.rectangle/3`\n\n```tucan\nTucan.layers([\n  Tucan.Geometry.rectangle({-2, 10}, {7, -3}, line_color: \"green\"),\n  Tucan.Geometry.rectangle({-3.5, 0.1}, {8.1, -4.2},\n    fill_color: \"pink\",\n    fill_opacity: 0.3\n  ),\n  Tucan.Geometry.polyline([{1, 1}, {2, 7}, {5, 3}],\n    closed: true,\n    fill_color: \"green\",\n    fill_opacity: 0.3\n  )\n])\n|> Tucan.Scale.set_xy_domain(-5, 11)\n```\n\n- Support setting plot's background color through `Tucan.View.set_background/2`\n- Support setting view's background color through `Tucan.View.set_view_background/2`\n- Add `Tucan.Axes.set_offset/3`\n- Add `Tucan.Legend.set_offset/3`\n- Support setting axes orientation with `Tucan.Axes.set_orientation/3`\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\")\n|> Tucan.Axes.set_orientation(:y, :right)\n```\n\n- Add `Tucan.Scale.set_scale/4` and enable passing scale options.\n- Add `Tucan.href_by/2`.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added plot options - Changelog","doc":"- Support `:point_shape`, `:point_size` and `:point_color` in `Tucan.stripplot/3`.\n- Support uniform jittering through `:jitter_mode` in `Tucan.Stripplot/3`.\n- Support stacked mode in `Tucan.density/3`.\n\n#","ref":"changelog.html#added-plot-options"},{"type":"extras","title":"Changed - Changelog","doc":"- Flipped `:orient` semantics for `Tucan.bar/4`\n- Rename `:group` option to `:group_by` in `Tucan.stripplot/3` for consistency.\n- Rename `:groupby` option to `:group_by` in `Tucan.density/3` for consistency.\n- Rename `:area_color` option to `:fill_color` in `Tucan.density/3` for consistency.\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecate `Tucan.circle/4` in favour of `Tucan.Geometry.circle/3`\n\n## [v0.2.1](https://github.com/pnezis/tucan/tree/v0.2.1) (2023-10-17)\n\n#","ref":"changelog.html#deprecated"},{"type":"extras","title":"Added - Changelog","doc":"- Support conditional text color in heatmaps using the `:text_color` option.\n\n```tucan\nTucan.heatmap(:glue, \"Task\", \"Model\", \"Score\",\n  annotate: true,\n  text: [format: \".1f\"],\n  text_color: [{nil, 40, \"black\"}, {40, 80, \"white\"}, {60, nil, \"yellow\"}]\n)\n|> Tucan.set_size(250, 250)\n```\n\n- Add `Tucan.annotate/5` auxiliary plot for adding text to a plot\n\n```tucan\nTucan.new()\n|> Tucan.annotate(10, 10, \"Hello\", color: :red, font_size: 20)\n|> Tucan.annotate(15, 12, \"world...\", color: :green, font_weight: :bold)\n|> Tucan.Scale.set_xy_domain(8, 17)\n```\n\n- Add `Tucan.Layers` with helper layers related functions.\n- Add `Tucan.background_image/2` helper function.\n\n- Add `Tucan.circle/4` helper function\n\n```tucan\nTucan.new()\n|> Tucan.circle({3, 2}, 5, line_color: \"purple\")\n|> Tucan.circle({-1, 6}, 2, line_color: \"red\")\n|> Tucan.circle({0, 1}, 4, line_color: \"green\", stroke_width: 3)\n|> Tucan.Scale.set_xy_domain(-4, 8)\n```\n\n- Add `Tucan.Scale.set_xy_domain/3`\n- Support setting multi-line string in `Tucan.set_title/3`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added plot options - Changelog","doc":"- Support `:only` in all plots. Using `:only` you can select only a subset of the input dataset for the current plot.\n- Support `:point_color` in `Tucan.lineplot/4`\n- Support `:area_color` and `:filled` in density plot\n- Support `:stroke_dash` in `Tucan.ruler/4`, `Tucan.hruler/3` and `Tucan.vruler/3`\n- Support `:stroke_dash` in `Tucan.lineplot/4`\n\n## [v0.2.0](https://github.com/pnezis/tucan/tree/v0.2.0) (2023-09-23)\n\n#","ref":"changelog.html#added-plot-options"},{"type":"extras","title":"Added - Changelog","doc":"- Add `Tucan.jointplot/4` composite plot.\n\n```tucan\n  Tucan.jointplot(\n    :penguins, \"Beak Length (mm)\", \"Beak Depth (mm)\",\n    marginal: :density,\n    color_by: \"Species\",\n    marginal_opts: [fill_opacity: 0.5]\n  )\n```\n\n- Add `Tucan.punchcard/5` plot. This is similar to heatmap but the third\n  dimension is encoded by size instead of color.\n\n```tucan\nTucan.punchcard(:glue, \"Task\", \"Model\", \"Score\")\n|> Tucan.color_by(\"Score\", recursive: true, type: :quantitative)\n|> Tucan.set_size(250, 250)\n```\n\n- Add `Tucan.heatmap/5` plot.\n\n```tucan\nTucan.heatmap(:glue, \"Task\", \"Model\", \"Score\", annotate: true, text: [format: \".1f\"])\n|> Tucan.set_size(250, 250)\n```\n\n- Add `Tucan.hruler/2`, `Tucan.vruler/2` and `Tucan.ruler/4` helpers.\n\n```tucan\nTucan.scatter(:iris, \"petal_width\", \"petal_length\", width: 300)\n|> Tucan.hruler(3, line_color: \"green\")\n|> Tucan.vruler(\"petal_width\", color_by: \"species\", stroke_width: 3)\n|> Tucan.hruler(\"petal_length\", color_by: \"species\")\n```\n\n- Add `Tucan.Legend` module for customizing legend properties.\n- Add `Tucan.Scale` helper module with helper functions for working with\n  scales, like `Tucan.Scale.set_color_scheme/3`.\n- Add `Tucan.set_size/3` helper for setting both width and height at once.\n- Add `Tucan.Axes.set_xy_titles/3` for setting axes titles at once.\n- Port more themes from `vega-themes`, check `Tucan.Themes` for all\n  available themes.\n\n- Add `Tucan.layers/2` helper\n\n```tucan\nTucan.layers(\n  [\n    Tucan.scatter(:iris, \"petal_width\", \"petal_length\", point_color: \"red\"),\n    Tucan.scatter(:iris, \"sepal_width\", \"sepal_length\", point_color: \"green\")\n  ]\n)\n```\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added plots options - Changelog","doc":"- Support `:filled` option in `Tucan.scatter/4`\n- Support `:wrapped` mode in `Tucan.facet_by/4`\n- Support `:color_by` option in `Tucan.stripplot/3`\n- Support `:line_color` option in `Tucan.lineplot/4`\n- Support `:point_color`, `:point_shape` and `:point_size` in `Tucan.scatter/4`\n\n#","ref":"changelog.html#added-plots-options"},{"type":"extras","title":"Fixed - Changelog","doc":"- Support setting `:orient` in `Tucan.density/3`.\n- Make size encodings quantitative by default.\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Made `Tucan.VegaLiteUtils` private.\n- `Tucan.Axes.put_axis_options` is renamed to `Tucan.Axes.put_options/3`\n- Rename `:groupby` to `:group_by` in `Tucan.boxplot/3` options.\n\n## [v0.1.1](https://github.com/pnezis/tucan/tree/v0.1.1) (2023-08-29)\n\n#","ref":"changelog.html#deprecated"},{"type":"extras","title":"Added - Changelog","doc":"- Add `concat/2`, `hconcat/2` and `vconcat/2` helper concatenation functions.\n\n## [v0.1.0](https://github.com/pnezis/tucan/tree/v0.1.0) (2023-08-28)\n\nInitial release.","ref":"changelog.html#added"},{"type":"extras","title":"LICENSE","doc":"# MIT License\n\nCopyright (c) 2023 Panagiotis Nezis\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Time Series Plots in Tucan","doc":"# Time Series Plots in Tucan\n\n```elixir\n# Comment this out for running from the path\n# System.put_env(\"TUCAN_DEV\", \"true\")\n\ntucan_version =\n  case System.get_env(\"TUCAN_DEV\") do\n    nil -> \"~> 0.3.0\"\n    _other -> [path: Path.expand(\"..\", __DIR__)]\n  end\n\nMix.install([\n  {:tucan, tucan_version},\n  {:kino_vega_lite, \"~> 0.1.10\"}\n])\n\nalias VegaLite, as: Vl\n```","ref":"time_series_plots_in_tucan.html"},{"type":"extras","title":"Introduction - Time Series Plots in Tucan","doc":"_This tutorial is an adaptation to Tucan of [Basic Time Series Plots in Vega-Lite](https://observablehq.com/@jonfroehlich/basic-time-series-plots-in-vega-lite?collection=@jonfroehlich/intro-to-vega-lite) by Jon E. Froehlich_\n\nWe will explore creating visualizations of **Seattle's daily maximum temperature** showing how to use position, color, and size to create multi-dimensional plots. We will create temporal scatter plots, dot/strip plots, heatmaps, and bubble plots.\n\nWe will then show how to use Tucan's functionalities to calculate and plot average monthly weather data.","ref":"time_series_plots_in_tucan.html#introduction"},{"type":"extras","title":"Our first visualization - scatter - Time Series Plots in Tucan","doc":"> Throughout this notebook we will use the `:weather` dataset that comes with `Tucan`.\n\nWe can start by using `Tucan.scatter/4 ` to plot all dataset points. Let's encode time on the _x-axis_ and `temp_max` on the _y-axis_. By default `scatter` expects two quantitative variables. We have to specify that the _x-axis_ encodes time by explicitely setting the `type` to `temporal` through the `:x` option.\n\nWe set the `filled` option to `true` in order to have filled points and enable the `tooltip` in order to add some interactivity.\n\n```elixir\nmax_temp_scatter =\n  Tucan.scatter(:weather, \"date\", \"temp_max\", filled: true, x: [type: :temporal], tooltip: true)\n  |> Tucan.set_size(700, 400)\n  |> Tucan.set_title(\"Daily Max Temperatures in Seattle 2012 - 2015\")\n  |> Tucan.Axes.set_y_title(\"Max Temperature\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#our-first-visualization-scatter"},{"type":"extras","title":"Semantic grouping by color - Time Series Plots in Tucan","doc":"We can also add **weather** as an additional encoding channel using color. To control the color palette, we set the color scale.\n\nSince we want to control the visual values, we specify a range. We carefully choose a palette that has semantic meaning: yellow for sun, gray for fog, blue for rain, etc.\n\nYou can either pipe the previous plot through `Tucan.color_by/3` or set directly the `color_by` option to the `Tucan.scatter/4` call.\n\n```elixir\ncolor_palette = [\"#aec7e8\", \"#c7c7c7\", \"#1f77b4\", \"#9467bd\", \"#e7ba52\"]\n\nTucan.color_by(max_temp_scatter, \"weather\")\n|> Tucan.Scale.set_color_scheme(color_palette)\n```\n\n#","ref":"time_series_plots_in_tucan.html#semantic-grouping-by-color"},{"type":"extras","title":"Semantic grouping by size - Time Series Plots in Tucan","doc":"We can also control the size of the points by a fourth variable. Let's use `precipitation` for this. Notice that we also set the range of the `size` encoding in order to ensure that all points are included in the graph.\n\nNotice how the tooltip content changes with respect to the encoded parameters.\n\n```elixir\nmax_temp_scatter\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.size_by(\"precipitation\", scale: [range: [5, 350]])\n```\n\n#","ref":"time_series_plots_in_tucan.html#semantic-grouping-by-size"},{"type":"extras","title":"Aggregating around month - Time Series Plots in Tucan","doc":"To track seasonal patterns, let's aggregate the temporal dimension around the `monthdate` time unit, which is sensitive to month and date but not year—and can be useful for binning time values to look at seasonal patterns.\n\nLet's also specifically format the _x-axis_ date format to print out the abbreviated month name. See [Vega-Lite's text format documentation](https://vega.github.io/vega-lite/docs/format.html) for more details. We will use the `Tucan.Axes.put_options/3` helper which can set any option on the given axis.\n\nAlso notice that the `:y` option (like all encoding options) can be used to set any arbitrary option to the `y` encoding channel.\n\n```elixir\naggregated_scatter =\n  Tucan.scatter(:weather, \"date\", \"temp_max\",\n    x: [type: :temporal, time_unit: :monthdate],\n    y: [aggregate: :mean],\n    width: 700,\n    height: 400\n  )\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.size_by(\"precipitation\", type: :quantitative, scale: [range: [5, 350]])\n  |> Tucan.set_title(\"Daily Max Temperatures in Seattle 2012 - 2015\")\n  |> Tucan.Axes.set_y_title(\"Max Temperature\")\n  |> Tucan.Axes.set_x_title(\"Aggregated Months (2012-2015)\")\n  |> Tucan.Axes.put_options(:x, format: \"%b\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#aggregating-around-month"},{"type":"extras","title":"Faceting the plot - Time Series Plots in Tucan","doc":"We can use the `Tucan.facet_by/4` function to split the plot into small multiples. Let's split the above graph by `weather` in order to highlight weather-based temporal trends.\n\nYou can use various helper methods to modify things like the legend position or reset the dimensions of a plot or the axes titles.\n\n```elixir\naggregated_scatter\n|> Tucan.facet_by(:column, \"weather\")\n|> Tucan.set_size(130, 140)\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"bottom\")\n|> Tucan.Legend.set_orientation(:size, \"bottom\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#faceting-the-plot"},{"type":"extras","title":"Combining two plots using concatenation - Time Series Plots in Tucan","doc":"We can use `Tucan`'s concat methods to combine plots vertically or horizontally. This is a form of view composition. We can combine plots horizontally with `Tucan.hconcat/2`, vertically with `Tucan.vconcat/2`, or via a general wrappable `Tucan.concat/2`.\n\nLet's combine both a bar-based frequency plot with this temporal plot.\n\n```elixir\nfrequencies =\n  Tucan.countplot(:weather, \"weather\", orient: :vertical, width: 700)\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.Axes.set_x_title(\"Num of Days with Weather (2012-2015)\")\n\nTucan.vconcat([aggregated_scatter, frequencies])\n```","ref":"time_series_plots_in_tucan.html#combining-two-plots-using-concatenation"},{"type":"extras","title":"Stripplot - Time Series Plots in Tucan","doc":"A strip plot is another way to explore variations in weather over time. In this case, let's encode the **date by month** along the _x-axis_, the **date by year** on the _y-axis_, and **weather** via color.\n\n```elixir\nstrip =\n  Tucan.stripplot(:weather, \"date\",\n    group_by: \"date\",\n    x: [time_unit: :monthdate, type: :temporal],\n    y: [time_unit: :year, type: :ordinal],\n    width: 700,\n    fill_opacity: 1\n  )\n  |> Tucan.color_by(\"weather\", scale: [range: color_palette])\n  |> Tucan.Axes.set_y_title(\"Year\")\n  |> Tucan.Axes.set_x_title(\"Month\")\n  |> Tucan.Axes.put_options(:x, format: \"%b\")\n```\n\nWe could add in a fourth dimension by encoding the **tick size** as a function of the **max_temp** field that day.\n\n```elixir\nstrip\n|> Tucan.size_by(\"temp_max\")\n|> Tucan.set_height(140)\n```\n\nYou could also change the `:mode` to `:jitter` to plot jittered points instead of ticks.\n\n```elixir\nTucan.stripplot(:weather, \"date\",\n  group_by: \"date\",\n  style: :jitter,\n  x: [time_unit: :monthdate, type: :temporal],\n  y: [time_unit: :year, type: :ordinal],\n  fill_opacity: 1\n)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.Axes.set_y_title(\"Year\")\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Axes.put_options(:x, format: \"%b\")\n|> Tucan.set_size(700, 300)\n```\n\n#","ref":"time_series_plots_in_tucan.html#stripplot"},{"type":"extras","title":"Strip plot split by weather - Time Series Plots in Tucan","doc":"Rather than encoding **year** on the `y-axis`, let's encode the **weather**.\n\n```elixir\nTucan.stripplot(:weather, \"date\",\n  group_by: \"weather\",\n  x: [time_unit: :monthdate, type: :temporal],\n  width: 700,\n  fill_opacity: 1\n)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.Axes.set_y_title(\"Weather\")\n|> Tucan.Axes.set_x_title(\"Month\")\n|> Tucan.Axes.put_options(:x, format: \"%b\")\n```","ref":"time_series_plots_in_tucan.html#strip-plot-split-by-weather"},{"type":"extras","title":"Distribution plots - Time Series Plots in Tucan","doc":"Tucan provides several plot types for displaying the distribution of a numerical variable. Let's start by plotting the boxplots of the `temp_max` for the various `weather` types.\n\n```elixir\nTucan.boxplot(:weather, \"temp_max\", group_by: \"weather\")\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.set_width(500)\n```\n\nWe could also use `Tucan.errorbar/3`.\n\n```elixir\nTucan.errorbar(:weather, \"temp_max\",\n  group_by: \"weather\",\n  points: true,\n  ticks: true,\n  extent: :ci\n)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.set_width(500)\n```\n\nSimilarly we could use `Tucan.stripplot/3` this time encoding the `temp_max` on the *x-axis*. Notice that we use `uniform` jittering.\n\n```elixir\nTucan.stripplot(:weather, \"temp_max\", group_by: \"weather\", style: :jitter, jitter_mode: :uniform)\n|> Tucan.color_by(\"weather\", scale: [range: color_palette])\n|> Tucan.set_width(500)\n|> Tucan.set_height(300)\n```","ref":"time_series_plots_in_tucan.html#distribution-plots"},{"type":"extras","title":"Weather heatmaps - Time Series Plots in Tucan","doc":"A heatmap uses color to encode the magnitude of a value.\n\nLet's use a heatmap to examine how Seattle's max temperature changes over the year. For this, we will encode the **date by day** along the _x-axis_, the **date by month** along the _y-axis_, and the **average temp_max** as _color_.\n\n```elixir\nheatmap =\n  Tucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n    x: [time_unit: :date],\n    y: [time_unit: :month],\n    color: [aggregate: :mean]\n  )\n  |> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n  |> Tucan.Axes.set_x_title(\"Day\")\n  |> Tucan.Axes.set_y_title(\"Month\")\n  |> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#weather-heatmaps"},{"type":"extras","title":"Changing the heatmap color scheme - Time Series Plots in Tucan","doc":"Let's change the color scheme to something more semantic with **high** temperature values mapped to **red** and **low** temperature values mapped to **blue**. See the [Vega-Lite color scheme documentation](https://vega.github.io/vega/docs/schemes/) for more details on available schemes.\n\nThe only change to the previous plot is that we will change the `:color` encoding scheme. We can use the `Tucan.Scale.set_color_scheme/3` helper to easily set or change the color scheme of an existing plot. We  use the `reverse: true` option in order to make the **low** temperatures blue and the **high** temperatures red.\n\n```elixir\nTucan.Scale.set_color_scheme(heatmap, :redyellowblue, reverse: true)\n```\n\n#","ref":"time_series_plots_in_tucan.html#changing-the-heatmap-color-scheme"},{"type":"extras","title":"Adding in heatmap cells the labels - Time Series Plots in Tucan","doc":"You can add annotations by setting the `:annotate` option to `true`. This will add a `:text` encoding to the plot which you can configure like all other encodings through the `:text` option. You can also conditionally color the text using `:text_color`\n\n```elixir\nTucan.heatmap(:weather, \"date\", \"date\", \"temp_max\",\n  annotate: true,\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  color: [aggregate: :mean],\n  text: [format: \".1f\"],\n  text_color: [{nil, 9, \"white\"}, {25, nil, \"white\"}]\n)\n|> Tucan.set_title(\"Heatmap of Avg Max Temperatures in Seattle (2012-2015)\")\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:color, \"Avg Max Temp\")\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.set_width(800)\n```","ref":"time_series_plots_in_tucan.html#adding-in-heatmap-cells-the-labels"},{"type":"extras","title":"Punchcard Plots - Time Series Plots in Tucan","doc":"Similar to the `heatmap` example, we can also make a `punchcard` to explore temporal Seattle weather patterns.\n\nWe'll use roughly the same encodings as before but this time map the average **temp_max** to circle **size**.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:size, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#punchcard-plots"},{"type":"extras","title":"Add dual encoding of temp max - Time Series Plots in Tucan","doc":"We could also set a dual encoding where both **color** and **size** encode the average **temp_max** field. Notice that since this is a layered plot we also need to set `recursive: true` in the `Tucan.color_by/3` call.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"temp_max\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_title(:size, \"Avg Max Temp\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#add-dual-encoding-of-temp-max"},{"type":"extras","title":"Encode precipitation as mark size - Time Series Plots in Tucan","doc":"Alternatively, we could encode **precipitation** as mark **size**.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#encode-precipitation-as-mark-size"},{"type":"extras","title":"Encode both temperature and precipitation - Time Series Plots in Tucan","doc":"You can encode add both **temperature** and **precipitation** to the same punchcard plot by using both **color** and **size** encodings.\n\nWe are also using `Tucan.Legend.set_orientation/3` helper to change the position of the two legends.\n\n```elixir\nTucan.punchcard(:weather, \"date\", \"date\", \"precipitation\",\n  x: [time_unit: :date],\n  y: [time_unit: :month],\n  size: [aggregate: :mean]\n)\n|> Tucan.color_by(\"temp_max\", aggregate: :mean, type: :quantitative, recursive: true)\n|> Tucan.Scale.set_color_scheme(:redyellowblue, reverse: true)\n|> Tucan.Axes.set_x_title(\"Day\")\n|> Tucan.Axes.set_y_title(\"Month\")\n|> Tucan.Legend.set_orientation(:color, \"top\")\n|> Tucan.Legend.set_orientation(:size, \"top\")\n```","ref":"time_series_plots_in_tucan.html#encode-both-temperature-and-precipitation"},{"type":"extras","title":"Lineplots - Plotting average monthly temperatures - Time Series Plots in Tucan","doc":"While useful to graph the raw data above, aggregating our data along higher-order temporal dimensions like month or year might help highlight additional trends. Let's try graphing the average maximum temperature in Seattle by month from 2012-2015.\n\nWe can do this by combining Vega-Lite's `:time_unit` and `:aggregate` properties. We will specify that we want the _x-axis_ in **months** and to aggregate using the **mean**.\n\nWe will use `Tucan.lineplot/4` to plot the seasonal trend. By setting `points: true` we include the points to the line plot.\n\n```elixir\navg_temperature =\n  Tucan.lineplot(:weather, \"date\", \"temp_max\",\n    x: [time_unit: :month, type: :temporal],\n    y: [aggregate: :mean],\n    points: true,\n    tooltip: true,\n    width: 700\n  )\n  |> Tucan.set_title(\"Average Daily Max Temperatures in Seattle (2012-2015) by Month\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#lineplots-plotting-average-monthly-temperatures"},{"type":"extras","title":"Adding annotations for daily max average - Time Series Plots in Tucan","doc":"We can add in an average line using `Tucan.hruler/3`. We can add a line either on a specific _y-axis_ point or on a calculated point.\n\n```elixir\nTucan.hruler(avg_temperature, \"temp_max\", line_color: \"red\")\n```\n\n#","ref":"time_series_plots_in_tucan.html#adding-annotations-for-daily-max-average"},{"type":"extras","title":"Lines by weather type - Time Series Plots in Tucan","doc":"Similarly to all other plots we can use `color_by` to plot multiple lines for each **weather type**. Additionally we will use `stroke_dash_by` to make the plot more accessible.\n\n```elixir\nTucan.lineplot(:weather, \"date\", \"temp_max\",\n  x: [time_unit: :month, type: :temporal],\n  y: [aggregate: :mean],\n  points: true,\n  tooltip: true\n)\n|> Tucan.color_by(\"weather\")\n|> Tucan.Scale.set_color_scheme(color_palette)\n|> Tucan.stroke_dash_by(\"weather\")\n|> Tucan.set_title(\"Average Daily Max Temperatures in Seattle (2012-2015) by Month & Weather\")\n|> Tucan.set_size(700, 350)\n```\n\n#","ref":"time_series_plots_in_tucan.html#lines-by-weather-type"},{"type":"extras","title":"Showing the confidence interval - Time Series Plots in Tucan","doc":"We can use `Tucan.errorband/4` to plot the confidence interval. We also color by the weather type in order to display the max temperatures intervals by weather type.\n\n```elixir\nTucan.errorband(:weather, \"date\", \"temp_max\", x: [time_unit: :month, type: :temporal])\n|> Tucan.color_by(\"weather\")\n|> Tucan.Scale.set_color_scheme(color_palette)\n|> Tucan.set_title(\"Daily Max Temperatures in Seattle (2012-2015) by Month & Weather\")\n|> Tucan.set_size(700, 350)\n```\n\nUsually you want to overlay the confidence intervals with the trend lines. You can achieve this by using the `Tucan.layers/2` helper.\n\n```elixir\nerrorbands =\n  Tucan.errorband(:weather, \"date\", \"temp_max\", x: [time_unit: :month, type: :temporal])\n\ntrend_lines =\n  Tucan.lineplot(:weather, \"date\", \"temp_max\",\n    x: [time_unit: :month, type: :temporal],\n    y: [aggregate: :mean],\n    points: true,\n    tooltip: true\n  )\n\nTucan.layers([errorbands, trend_lines])\n|> Tucan.set_title(\"Daily Max Temperatures in Seattle (2012-2015) by Month & Weather\")\n|> Tucan.set_size(700, 350)\n|> Tucan.color_by(\"weather\", recursive: true)\n|> Tucan.Scale.set_color_scheme(color_palette)\n```","ref":"time_series_plots_in_tucan.html#showing-the-confidence-interval"},{"type":"extras","title":"Composite Plots - Time Series Plots in Tucan","doc":"```elixir\nTucan.jointplot(:weather, \"temp_max\", \"precipitation\",\n  color_by: \"weather\",\n  ratio: 0.3,\n  fill_opacity: 0.5\n)\n```\n\n```elixir\nTucan.pairplot(:weather, [\"temp_min\", \"temp_max\", \"precipitation\", \"wind\"], diagonal: :histogram)\n|> Tucan.color_by(\"weather\", recursive: true)\n|> Tucan.Legend.set_orientation(:color, \"top\")\n\n# |> Tucan.Scale.set_color_scheme(color_palette)\n```","ref":"time_series_plots_in_tucan.html#composite-plots"}],"content_type":"text/markdown"}